@@ -1,11 +1,11 @@
-# -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-from astropy.utils.decorators import format_doc
 from astropy.coordinates.baseframe import base_doc
+from astropy.utils.decorators import format_doc
+
 from .baseradec import BaseRADecFrame, doc_components
 
-__all__ = ['ICRS']
+__all__ = ["ICRS"]
 
 
 @format_doc(base_doc, components=doc_components, footer="")
@@ -19,6 +19,6 @@ class ICRS(BaseRADecFrame):
     very close (within tens of milliarcseconds) to J2000 equatorial.
 
     For more background on the ICRS and related coordinate transformations, see
-    the references provided in the  :ref:`astropy-coordinates-seealso` section
-    of the documentation.
+    the references provided in the  :ref:`astropy:astropy-coordinates-seealso`
+    section of the documentation.
     """
