@@ -2,29 +2,30 @@
 
 """Testing :mod:`astropy.cosmology.flrw.base`."""
 
-##############################################################################
-# IMPORTS
-
-# STDLIB
 import abc
 import copy
 
-# THIRD PARTY
 import numpy as np
 import pytest
 
 import astropy.constants as const
-# LOCAL
 import astropy.units as u
-from astropy.cosmology import FLRW, FlatLambdaCDM, LambdaCDM, Planck18
+from astropy.cosmology import FLRW, FlatLambdaCDM, LambdaCDM, Parameter, Planck18
 from astropy.cosmology.core import _COSMOLOGY_CLASSES
 from astropy.cosmology.flrw.base import _a_B_c2, _critdens_const, _H0units_to_invs, quad
-from astropy.cosmology.parameter import Parameter
+from astropy.cosmology.parameter._core import MISSING
 from astropy.cosmology.tests.helper import get_redshift_methods
-from astropy.cosmology.tests.test_core import CosmologySubclassTest as CosmologyTest
 from astropy.cosmology.tests.test_core import (
-    FlatCosmologyMixinTest, ParameterTestMixin, invalid_zs, valid_zs)
-from astropy.utils.compat.optional_deps import HAS_SCIPY
+    CosmologyTest,
+    FlatCosmologyMixinTest,
+    ParameterTestMixin,
+    invalid_zs,
+    valid_zs,
+)
+from astropy.tests.helper import assert_quantity_allclose
+from astropy.utils.compat.optional_deps import HAS_PANDAS, HAS_SCIPY
+
+from .conftest import filter_keys_from_items
 
 ##############################################################################
 # SETUP / TEARDOWN
@@ -46,6 +47,7 @@ def test_optional_deps_functions():
     with pytest.raises(ModuleNotFoundError, match="No module named 'scipy.integrate'"):
         quad()
 
+
 ##############################################################################
 
 
@@ -62,15 +64,17 @@ class ParameterH0TestMixin(ParameterTestMixin):
         unit = u.Unit("km/(s Mpc)")
 
         # on the class
-        assert isinstance(cosmo_cls.H0, Parameter)
-        assert "Hubble constant" in cosmo_cls.H0.__doc__
-        assert cosmo_cls.H0.unit == unit
+        H0 = cosmo_cls.parameters["H0"]
+        assert isinstance(H0, Parameter)
+        assert "Hubble constant" in H0.__doc__
+        assert H0.unit == unit
+        assert H0.default is MISSING
 
         # validation
-        assert cosmo_cls.H0.validate(cosmo, 1) == 1 * unit
-        assert cosmo_cls.H0.validate(cosmo, 10 * unit) == 10 * unit
+        assert H0.validate(cosmo, 1) == 1 * unit
+        assert H0.validate(cosmo, 10 * unit) == 10 * unit
         with pytest.raises(ValueError, match="H0 is a non-scalar quantity"):
-            cosmo_cls.H0.validate(cosmo, [1, 2])
+            H0.validate(cosmo, [1, 2])
 
         # on the instance
         assert cosmo.H0 is cosmo._H0
@@ -105,14 +109,16 @@ class ParameterOm0TestMixin(ParameterTestMixin):
     def test_Om0(self, cosmo_cls, cosmo):
         """Test Parameter ``Om0``."""
         # on the class
-        assert isinstance(cosmo_cls.Om0, Parameter)
-        assert "Omega matter" in cosmo_cls.Om0.__doc__
+        Om0 = cosmo_cls.parameters["Om0"]
+        assert isinstance(Om0, Parameter)
+        assert "Omega matter" in Om0.__doc__
+        assert Om0.default is MISSING
 
         # validation
-        assert cosmo_cls.Om0.validate(cosmo, 1) == 1
-        assert cosmo_cls.Om0.validate(cosmo, 10 * u.one) == 10
+        assert Om0.validate(cosmo, 1) == 1
+        assert Om0.validate(cosmo, 10 * u.one) == 10
         with pytest.raises(ValueError, match="Om0 cannot be negative"):
-            cosmo_cls.Om0.validate(cosmo, -1)
+            Om0.validate(cosmo, -1)
 
         # on the instance
         assert cosmo.Om0 is cosmo._Om0
@@ -147,15 +153,22 @@ class ParameterOde0TestMixin(ParameterTestMixin):
 
     def test_Parameter_Ode0(self, cosmo_cls):
         """Test Parameter ``Ode0`` on the class."""
-        assert isinstance(cosmo_cls.Ode0, Parameter)
-        assert "Omega dark energy" in cosmo_cls.Ode0.__doc__
+        Ode0 = cosmo_cls.parameters.get(
+            "Ode0", cosmo_cls._derived_parameters.get("Ode0")
+        )
+        assert isinstance(Ode0, Parameter)
+        assert "Omega dark energy" in Ode0.__doc__
+        assert Ode0.default is MISSING
 
     def test_Parameter_Ode0_validation(self, cosmo_cls, cosmo):
         """Test Parameter ``Ode0`` validation."""
-        assert cosmo_cls.Ode0.validate(cosmo, 1.1) == 1.1
-        assert cosmo_cls.Ode0.validate(cosmo, 10 * u.one) == 10.0
+        Ode0 = cosmo_cls.parameters.get(
+            "Ode0", cosmo_cls._derived_parameters.get("Ode0")
+        )
+        assert Ode0.validate(cosmo, 1.1) == 1.1
+        assert Ode0.validate(cosmo, 10 * u.one) == 10.0
         with pytest.raises(TypeError, match="only dimensionless"):
-            cosmo_cls.Ode0.validate(cosmo, 10 * u.km)
+            Ode0.validate(cosmo, 10 * u.km)
 
     def test_Ode0(self, cosmo):
         """Test Parameter ``Ode0`` validation."""
@@ -199,15 +212,17 @@ class ParameterTcmb0TestMixin(ParameterTestMixin):
     def test_Tcmb0(self, cosmo_cls, cosmo):
         """Test Parameter ``Tcmb0``."""
         # on the class
-        assert isinstance(cosmo_cls.Tcmb0, Parameter)
-        assert "Temperature of the CMB" in cosmo_cls.Tcmb0.__doc__
-        assert cosmo_cls.Tcmb0.unit == u.K
+        Tcmb0 = cosmo_cls.parameters["Tcmb0"]
+        assert isinstance(Tcmb0, Parameter)
+        assert "Temperature of the CMB" in Tcmb0.__doc__
+        assert Tcmb0.unit == u.K
+        assert Tcmb0.default == 0.0 * u.K
 
         # validation
-        assert cosmo_cls.Tcmb0.validate(cosmo, 1) == 1 * u.K
-        assert cosmo_cls.Tcmb0.validate(cosmo, 10 * u.K) == 10 * u.K
+        assert Tcmb0.validate(cosmo, 1) == 1 * u.K
+        assert Tcmb0.validate(cosmo, 10 * u.K) == 10 * u.K
         with pytest.raises(ValueError, match="Tcmb0 is a non-scalar quantity"):
-            cosmo_cls.Tcmb0.validate(cosmo, [1, 2])
+            Tcmb0.validate(cosmo, [1, 2])
 
         # on the instance
         assert cosmo.Tcmb0 is cosmo._Tcmb0
@@ -242,14 +257,16 @@ class ParameterNeffTestMixin(ParameterTestMixin):
     def test_Neff(self, cosmo_cls, cosmo):
         """Test Parameter ``Neff``."""
         # on the class
-        assert isinstance(cosmo_cls.Neff, Parameter)
-        assert "Number of effective neutrino species" in cosmo_cls.Neff.__doc__
+        Neff = cosmo_cls.parameters["Neff"]
+        assert isinstance(Neff, Parameter)
+        assert "Number of effective neutrino species" in Neff.__doc__
+        assert Neff.default == 3.04
 
         # validation
-        assert cosmo_cls.Neff.validate(cosmo, 1) == 1
-        assert cosmo_cls.Neff.validate(cosmo, 10 * u.one) == 10
+        assert Neff.validate(cosmo, 1) == 1
+        assert Neff.validate(cosmo, 10 * u.one) == 10
         with pytest.raises(ValueError, match="Neff cannot be negative"):
-            cosmo_cls.Neff.validate(cosmo, -1)
+            Neff.validate(cosmo, -1)
 
         # on the instance
         assert cosmo.Neff is cosmo._Neff
@@ -284,10 +301,12 @@ class Parameterm_nuTestMixin(ParameterTestMixin):
     def test_m_nu(self, cosmo_cls, cosmo):
         """Test Parameter ``m_nu``."""
         # on the class
-        assert isinstance(cosmo_cls.m_nu, Parameter)
-        assert "Mass of neutrino species" in cosmo_cls.m_nu.__doc__
-        assert cosmo_cls.m_nu.unit == u.eV
-        assert cosmo_cls.m_nu.equivalencies == u.mass_energy()
+        m_nu = cosmo_cls.parameters["m_nu"]
+        assert isinstance(m_nu, Parameter)
+        assert "Mass of neutrino species" in m_nu.__doc__
+        assert m_nu.unit == u.eV
+        assert m_nu.equivalencies == u.mass_energy()
+        assert m_nu.default == 0.0 * u.eV
 
         # on the instance
         # assert cosmo.m_nu is cosmo._m_nu
@@ -301,7 +320,7 @@ class Parameterm_nuTestMixin(ParameterTestMixin):
         elif self._nmasslessnu == 0:  # only massive
             assert cosmo.m_nu == cosmo._massivenu_mass
         else:  # a mix -- the most complicated case
-            assert u.allclose(cosmo.m_nu[:self._nmasslessnu], 0 * u.eV)
+            assert u.allclose(cosmo.m_nu[: self._nmasslessnu], 0 * u.eV)
             assert u.allclose(cosmo.m_nu[self._nmasslessnu], cosmo._massivenu_mass)
 
     def test_init_m_nu(self, cosmo_cls, ba):
@@ -348,7 +367,9 @@ class Parameterm_nuTestMixin(ParameterTestMixin):
         assert cosmo.m_nu.unit == u.eV
         assert u.allclose(cosmo.m_nu, 0 * u.eV)
         # TODO! move this test when create ``test_nu_relative_density``
-        assert u.allclose(cosmo.nu_relative_density(1.0), 0.22710731766 * 4.05, rtol=1e-6)
+        assert u.allclose(
+            cosmo.nu_relative_density(1.0), 0.22710731766 * 4.05, rtol=1e-6
+        )
 
         # All massive neutrinos case, len from Neff
         tba.arguments["m_nu"] = 0.1 * u.eV
@@ -390,17 +411,19 @@ class ParameterOb0TestMixin(ParameterTestMixin):
     def test_Ob0(self, cosmo_cls, cosmo):
         """Test Parameter ``Ob0``."""
         # on the class
-        assert isinstance(cosmo_cls.Ob0, Parameter)
-        assert "Omega baryon;" in cosmo_cls.Ob0.__doc__
+        Ob0 = cosmo_cls.parameters["Ob0"]
+        assert isinstance(Ob0, Parameter)
+        assert "Omega baryon;" in Ob0.__doc__
+        assert Ob0.default is None
 
         # validation
-        assert cosmo_cls.Ob0.validate(cosmo, None) is None
-        assert cosmo_cls.Ob0.validate(cosmo, 0.1) == 0.1
-        assert cosmo_cls.Ob0.validate(cosmo, 0.1 * u.one) == 0.1
+        assert Ob0.validate(cosmo, None) is None
+        assert Ob0.validate(cosmo, 0.1) == 0.1
+        assert Ob0.validate(cosmo, 0.1 * u.one) == 0.1
         with pytest.raises(ValueError, match="Ob0 cannot be negative"):
-            cosmo_cls.Ob0.validate(cosmo, -1)
+            Ob0.validate(cosmo, -1)
         with pytest.raises(ValueError, match="baryonic density can not be larger"):
-            cosmo_cls.Ob0.validate(cosmo, cosmo.Om0 + 1)
+            Ob0.validate(cosmo, cosmo.Om0 + 1)
 
         # on the instance
         assert cosmo.Ob0 is cosmo._Ob0
@@ -452,30 +475,33 @@ class ParameterOb0TestMixin(ParameterTestMixin):
         assert cosmo_cls._init_signature.parameters["Ob0"].default is None
 
 
-class TestFLRW(CosmologyTest,
-               ParameterH0TestMixin, ParameterOm0TestMixin, ParameterOde0TestMixin,
-               ParameterTcmb0TestMixin, ParameterNeffTestMixin, Parameterm_nuTestMixin,
-               ParameterOb0TestMixin):
-    """Test :class:`astropy.cosmology.FLRW`."""
-
-    abstract_w = True
+class FLRWTest(
+    CosmologyTest,
+    ParameterH0TestMixin,
+    ParameterOm0TestMixin,
+    ParameterOde0TestMixin,
+    ParameterTcmb0TestMixin,
+    ParameterNeffTestMixin,
+    Parameterm_nuTestMixin,
+    ParameterOb0TestMixin,
+):
+    abstract_w = False
 
+    @abc.abstractmethod
     def setup_class(self):
-        """
-        Setup for testing.
-        FLRW is abstract, so tests are done on a subclass.
-        """
-        # make sure SubCosmology is known
-        _COSMOLOGY_CLASSES["SubFLRW"] = SubFLRW
+        """Setup for testing."""
+        super().setup_class(self)
 
-        self.cls = SubFLRW
-        self._cls_args = dict(H0=70 * u.km / u.s / u.Mpc, Om0=0.27 * u.one, Ode0=0.73 * u.one)
-        self.cls_kwargs = dict(Tcmb0=3.0 * u.K, Ob0=0.03 * u.one,
-                               name=self.__class__.__name__, meta={"a": "b"})
-
-    def teardown_class(self):
-        super().teardown_class(self)
-        _COSMOLOGY_CLASSES.pop("SubFLRW", None)
+        # Default cosmology args and kwargs
+        self._cls_args = dict(
+            H0=70 * u.km / u.s / u.Mpc, Om0=0.27 * u.one, Ode0=0.73 * u.one
+        )
+        self.cls_kwargs = dict(
+            Tcmb0=3.0 * u.K,
+            Ob0=0.03 * u.one,
+            name=self.__class__.__name__,
+            meta={"a": "b"},
+        )
 
     @pytest.fixture(scope="class")
     def nonflatcosmo(self):
@@ -495,7 +521,7 @@ class TestFLRW(CosmologyTest,
     def test_init_Tcmb0_zeroing(self, cosmo_cls, ba):
         """Test if setting Tcmb0 parameter to 0 influences other parameters.
 
-        TODO: consider moving this test to ``FLRWSubclassTest``
+        TODO: consider moving this test to ``FLRWTest``
         """
         ba.arguments["Tcmb0"] = 0.0
         cosmo = cosmo_cls(*ba.args, **ba.kwargs)
@@ -534,7 +560,9 @@ class TestFLRW(CosmologyTest,
 
         # on the instance
         assert cosmo.Ok0 is cosmo._Ok0
-        assert np.allclose(cosmo.Ok0, 1.0 - (cosmo.Om0 + cosmo.Ode0 + cosmo.Ogamma0 + cosmo.Onu0))
+        assert np.allclose(
+            cosmo.Ok0, 1.0 - (cosmo.Om0 + cosmo.Ode0 + cosmo.Ogamma0 + cosmo.Onu0)
+        )
 
     def test_is_flat(self, cosmo_cls, cosmo):
         """Test property ``is_flat``."""
@@ -607,7 +635,7 @@ class TestFLRW(CosmologyTest,
 
         # on the instance
         assert cosmo.critical_density0 is cosmo._critical_density0
-        assert cosmo.critical_density0.unit == u.g / u.cm ** 3
+        assert cosmo.critical_density0.unit == u.g / u.cm**3
 
         cd0value = _critdens_const * (cosmo.H0.value * _H0units_to_invs) ** 2
         assert cosmo.critical_density0.value == cd0value
@@ -621,7 +649,7 @@ class TestFLRW(CosmologyTest,
         # on the instance
         assert cosmo.Ogamma0 is cosmo._Ogamma0
         # Ogamma cor \propto T^4/rhocrit
-        expect = _a_B_c2 * cosmo.Tcmb0.value ** 4 / cosmo.critical_density0.value
+        expect = _a_B_c2 * cosmo.Tcmb0.value**4 / cosmo.critical_density0.value
         assert np.allclose(cosmo.Ogamma0, expect)
         # check absolute equality to 0 if Tcmb0 is 0
         if cosmo.Tcmb0 == 0:
@@ -649,11 +677,216 @@ class TestFLRW(CosmologyTest,
             # check the expected formula
             assert cosmo.Onu0 == 0.22710731766 * cosmo._Neff * cosmo.Ogamma0
             # and check compatibility with nu_relative_density
-            assert np.allclose(cosmo.nu_relative_density(0), 0.22710731766 * cosmo._Neff)
+            assert np.allclose(
+                cosmo.nu_relative_density(0), 0.22710731766 * cosmo._Neff
+            )
 
     def test_Otot0(self, cosmo):
         """Test :attr:`astropy.cosmology.FLRW.Otot0`."""
-        assert cosmo.Otot0 == cosmo.Om0 + cosmo.Ogamma0 + cosmo.Onu0 + cosmo.Ode0 + cosmo.Ok0
+        assert (
+            cosmo.Otot0
+            == cosmo.Om0 + cosmo.Ogamma0 + cosmo.Onu0 + cosmo.Ode0 + cosmo.Ok0
+        )
+
+    # ---------------------------------------------------------------
+    # Methods
+
+    _FLRW_redshift_methods = get_redshift_methods(
+        FLRW, include_private=True, include_z2=False
+    )
+
+    @pytest.mark.skipif(not HAS_SCIPY, reason="scipy is not installed")
+    @pytest.mark.parametrize("z, exc", invalid_zs)
+    @pytest.mark.parametrize("method", sorted(_FLRW_redshift_methods))
+    def test_redshift_method_bad_input(self, cosmo, method, z, exc):
+        """Test all the redshift methods for bad input."""
+        with pytest.raises(exc):
+            getattr(cosmo, method)(z)
+
+    @pytest.mark.parametrize("z", valid_zs)
+    @abc.abstractmethod
+    def test_w(self, cosmo, z):
+        """Test :meth:`astropy.cosmology.FLRW.w`.
+
+        Since ``w`` is abstract, each test class needs to define further tests.
+        """
+        # super().test_w(cosmo, z)  # NOT b/c abstract `w(z)`
+        w = cosmo.w(z)
+        assert np.shape(w) == np.shape(z)  # test same shape
+        assert u.Quantity(w).unit == u.one  # test no units or dimensionless
+
+    # -------------------------------------------
+
+    @pytest.mark.parametrize("z", valid_zs)
+    def test_Otot(self, cosmo, z):
+        """Test :meth:`astropy.cosmology.FLRW.Otot`."""
+        # super().test_Otot(cosmo)  # NOT b/c abstract `w(z)`
+        assert np.allclose(
+            cosmo.Otot(z),
+            cosmo.Om(z) + cosmo.Ogamma(z) + cosmo.Onu(z) + cosmo.Ode(z) + cosmo.Ok(z),
+        )
+
+    def test_scale_factor0(self, cosmo):
+        """Test :meth:`astropy.cosmology.FLRW.scale_factor`."""
+        assert isinstance(cosmo.scale_factor0, u.Quantity)
+        assert cosmo.scale_factor0.unit == u.one
+        assert cosmo.scale_factor0 == 1
+        assert np.allclose(cosmo.scale_factor0, cosmo.scale_factor(0))
+
+    @pytest.mark.parametrize("z", valid_zs)
+    def test_scale_factor(self, cosmo, z):
+        """Test :meth:`astropy.cosmology.FLRW.scale_factor`."""
+        assert np.allclose(cosmo.scale_factor(z), 1 / (1 + np.array(z)))
+
+    @pytest.mark.skipif(
+        not (HAS_PANDAS and HAS_SCIPY), reason="requires pandas and scipy"
+    )
+    def test_luminosity_distance_pandas(self, cosmo):
+        """Test :meth:`astropy.cosmology.FLRW.luminosity_distance`.
+
+        Regression test for https://github.com/astropy/astropy/issues/15576.
+        """
+        import pandas as pd
+
+        z = pd.Series([0.1, 0.2, 0.3])
+        d = cosmo.luminosity_distance(z)
+
+        assert isinstance(d, u.Quantity)
+        assert d.unit == u.Mpc
+        np.testing.assert_array_equal(d, cosmo.luminosity_distance(np.array(z)))
+
+    # ---------------------------------------------------------------
+
+    def test_efunc_vs_invefunc(self, cosmo):
+        """Test that ``efunc`` and ``inv_efunc`` give inverse values.
+
+        Note that the test doesn't need scipy because it doesn't need to call
+        ``de_density_scale``.
+        """
+        # super().test_efunc_vs_invefunc(cosmo)  # NOT b/c abstract `w(z)`
+        z0 = 0.5
+        z = np.array([0.5, 1.0, 2.0, 5.0])
+
+        assert np.allclose(cosmo.efunc(z0), 1.0 / cosmo.inv_efunc(z0))
+        assert np.allclose(cosmo.efunc(z), 1.0 / cosmo.inv_efunc(z))
+
+    # ---------------------------------------------------------------
+    # from Cosmology
+
+    def test_clone_change_param(self, cosmo):
+        """Test method ``.clone()`` changing a(many) Parameter(s)."""
+        super().test_clone_change_param(cosmo)
+
+        # don't change any values
+        kwargs = dict(cosmo.parameters)
+        c = cosmo.clone(**kwargs)
+        assert c.__class__ == cosmo.__class__
+        assert c == cosmo
+
+        # change ``H0``
+        # Note that H0 affects Ode0 because it changes Ogamma0
+        c = cosmo.clone(H0=100)
+        assert c.__class__ == cosmo.__class__
+        assert c.name == cosmo.name + " (modified)"
+        assert c.H0.value == 100
+        for n, v in filter_keys_from_items(c.parameters, ("H0",)):
+            v_expect = getattr(cosmo, n)
+            if v is None:
+                assert v is v_expect
+            else:
+                assert_quantity_allclose(v, v_expect, atol=1e-4 * getattr(v, "unit", 1))
+        assert not u.allclose(c.Ogamma0, cosmo.Ogamma0)
+        assert not u.allclose(c.Onu0, cosmo.Onu0)
+
+        # change multiple things
+        c = cosmo.clone(name="new name", H0=100, Tcmb0=2.8, meta=dict(zz="tops"))
+        assert c.__class__ == cosmo.__class__
+        assert c.name == "new name"
+        assert c.H0.value == 100
+        assert c.Tcmb0.value == 2.8
+        assert c.meta == {**cosmo.meta, **dict(zz="tops")}
+        for n, v in filter_keys_from_items(c.parameters, ("H0", "Tcmb0")):
+            v_expect = getattr(cosmo, n)
+            if v is None:
+                assert v is v_expect
+            else:
+                assert_quantity_allclose(v, v_expect, atol=1e-4 * getattr(v, "unit", 1))
+        assert not u.allclose(c.Ogamma0, cosmo.Ogamma0)
+        assert not u.allclose(c.Onu0, cosmo.Onu0)
+        assert not u.allclose(c.Tcmb0.value, cosmo.Tcmb0.value)
+
+    def test_is_equivalent(self, cosmo):
+        """Test :meth:`astropy.cosmology.FLRW.is_equivalent`."""
+        super().test_is_equivalent(cosmo)  # pass to CosmologyTest
+
+        # test against a FlatFLRWMixin
+        # case (3) in FLRW.is_equivalent
+        if isinstance(cosmo, FlatLambdaCDM):
+            assert cosmo.is_equivalent(Planck18)
+            assert Planck18.is_equivalent(cosmo)
+        else:
+            assert not cosmo.is_equivalent(Planck18)
+            assert not Planck18.is_equivalent(cosmo)
+
+    # ===============================================================
+    # Usage Tests
+
+    # TODO: this test should be subsumed by other tests
+    @pytest.mark.parametrize("method", ("Om", "Ode", "w", "de_density_scale"))
+    def test_distance_broadcast(self, cosmo, method):
+        """Test distance methods broadcast z correctly."""
+        g = getattr(cosmo, method)
+        z = np.linspace(0.1, 1, 6)
+        z2d = z.reshape(2, 3)
+        z3d = z.reshape(3, 2, 1)
+
+        value_flat = g(z)
+        assert value_flat.shape == z.shape
+
+        value_2d = g(z2d)
+        assert value_2d.shape == z2d.shape
+
+        value_3d = g(z3d)
+        assert value_3d.shape == z3d.shape
+        assert u.allclose(value_flat, value_2d.flatten())
+        assert u.allclose(value_flat, value_3d.flatten())
+
+    @pytest.mark.skipif(not HAS_SCIPY, reason="scipy required for this test.")
+    def test_comoving_distance_example(self, cosmo_cls, args, kwargs, expected):
+        """Test :meth:`astropy.cosmology.LambdaCDM.comoving_distance`.
+
+        These do not come from external codes -- they are just internal checks to make
+        sure nothing changes if we muck with the distance calculators.
+        """
+        z = np.array([1.0, 2.0, 3.0, 4.0])
+
+        cosmo = cosmo_cls(*args, **kwargs)
+        assert u.allclose(cosmo.comoving_distance(z), expected, rtol=1e-4)
+
+
+class TestFLRW(FLRWTest):
+    """Test :class:`astropy.cosmology.FLRW`."""
+
+    abstract_w = True
+
+    def setup_class(self):
+        """
+        Setup for testing.
+        FLRW is abstract, so tests are done on a subclass.
+        """
+        super().setup_class(self)
+
+        # make sure SubCosmology is known
+        _COSMOLOGY_CLASSES["SubFLRW"] = SubFLRW
+
+        self.cls = SubFLRW
+
+    def teardown_class(self):
+        super().teardown_class(self)
+        _COSMOLOGY_CLASSES.pop("SubFLRW", None)
+
+    # ===============================================================
+    # Method & Attribute Tests
 
     # ---------------------------------------------------------------
     # Methods
@@ -682,134 +915,44 @@ class TestFLRW(CosmologyTest,
         with pytest.raises(exception):
             cosmo.inv_efunc(0.5)
 
-    # ---------------------------------------------------------------
-    # from Cosmology
+    @pytest.mark.skip(reason="w(z) is abstract")
+    def test_luminosity_distance_pandas(self, cosmo):
+        """Test :meth:`astropy.cosmology.FLRW.luminosity_distance`."""
 
-    def test_clone_change_param(self, cosmo):
-        """Test method ``.clone()`` changing a(many) Parameter(s)."""
-        super().test_clone_change_param(cosmo)
-
-        # don't change any values
-        kwargs = cosmo._init_arguments.copy()
-        kwargs.pop("name", None)  # make sure not setting name
-        kwargs.pop("meta", None)  # make sure not setting name
-        c = cosmo.clone(**kwargs)
-        assert c.__class__ == cosmo.__class__
-        assert c == cosmo
-
-        # change ``H0``
-        # Note that H0 affects Ode0 because it changes Ogamma0
-        c = cosmo.clone(H0=100)
-        assert c.__class__ == cosmo.__class__
-        assert c.name == cosmo.name + " (modified)"
-        assert c.H0.value == 100
-        for n in (set(cosmo.__parameters__) - {"H0"}):
-            v = getattr(c, n)
-            if v is None:
-                assert v is getattr(cosmo, n)
-            else:
-                assert u.allclose(v, getattr(cosmo, n), atol=1e-4 * getattr(v, "unit", 1))
-        assert not u.allclose(c.Ogamma0, cosmo.Ogamma0)
-        assert not u.allclose(c.Onu0, cosmo.Onu0)
-
-        # change multiple things
-        c = cosmo.clone(name="new name", H0=100, Tcmb0=2.8, meta=dict(zz="tops"))
-        assert c.__class__ == cosmo.__class__
-        assert c.name == "new name"
-        assert c.H0.value == 100
-        assert c.Tcmb0.value == 2.8
-        assert c.meta == {**cosmo.meta, **dict(zz="tops")}
-        for n in (set(cosmo.__parameters__) - {"H0", "Tcmb0"}):
-            v = getattr(c, n)
-            if v is None:
-                assert v is getattr(cosmo, n)
-            else:
-                assert u.allclose(v, getattr(cosmo, n), atol=1e-4 * getattr(v, "unit", 1))
-        assert not u.allclose(c.Ogamma0, cosmo.Ogamma0)
-        assert not u.allclose(c.Onu0, cosmo.Onu0)
-        assert not u.allclose(c.Tcmb0.value, cosmo.Tcmb0.value)
-
-    def test_is_equivalent(self, cosmo):
-        """Test :meth:`astropy.cosmology.FLRW.is_equivalent`."""
-        super().test_is_equivalent(cosmo)  # pass to CosmologySubclassTest
-
-        # test against a FlatFLRWMixin
-        # case (3) in FLRW.is_equivalent
-        if isinstance(cosmo, FlatLambdaCDM):
-            assert cosmo.is_equivalent(Planck18)
-            assert Planck18.is_equivalent(cosmo)
-        else:
-            assert not cosmo.is_equivalent(Planck18)
-            assert not Planck18.is_equivalent(cosmo)
-
-
-class FLRWSubclassTest(TestFLRW):
-    """
-    Test subclasses of :class:`astropy.cosmology.FLRW`.
-    This is broken away from ``TestFLRW``, because ``FLRW`` is an ABC and
-    subclasses must override some methods.
-    """
-
-    abstract_w = False
-
-    @abc.abstractmethod
-    def setup_class(self):
-        """Setup for testing."""
-        super().setup_class(self)
-
-    # ===============================================================
-    # Method & Attribute Tests
-
-    _FLRW_redshift_methods = get_redshift_methods(FLRW, include_private=True, include_z2=False)
+    _FLRW_redshift_methods = get_redshift_methods(
+        FLRW, include_private=True, include_z2=False
+    ) - {"w"}
 
     @pytest.mark.skipif(not HAS_SCIPY, reason="scipy is not installed")
     @pytest.mark.parametrize("z, exc", invalid_zs)
-    @pytest.mark.parametrize('method', _FLRW_redshift_methods)
+    @pytest.mark.parametrize("method", sorted(_FLRW_redshift_methods))
     def test_redshift_method_bad_input(self, cosmo, method, z, exc):
         """Test all the redshift methods for bad input."""
         with pytest.raises(exc):
             getattr(cosmo, method)(z)
 
-    @pytest.mark.parametrize("z", valid_zs)
-    @abc.abstractmethod
-    def test_w(self, cosmo, z):
-        """Test :meth:`astropy.cosmology.FLRW.w`.
+    # ===============================================================
+    # Usage Tests
 
-        Since ``w`` is abstract, each test class needs to define further tests.
-        """
-        # super().test_w(cosmo, z)  # NOT b/c abstract `w(z)`
-        w = cosmo.w(z)
-        assert np.shape(w) == np.shape(z)  # test same shape
-        assert u.Quantity(w).unit == u.one  # test no units or dimensionless
+    @pytest.mark.skipif(not HAS_SCIPY, reason="scipy required for this test.")
+    @pytest.mark.parametrize("method", ("Om", "Ode", "w", "de_density_scale"))
+    def test_distance_broadcast(self, cosmo, method):
+        with pytest.raises(NotImplementedError):
+            super().test_distance_broadcast(cosmo, method)
 
-    # -------------------------------------------
-
-    @pytest.mark.parametrize("z", valid_zs)
-    def test_Otot(self, cosmo, z):
-        """Test :meth:`astropy.cosmology.FLRW.Otot`."""
-        # super().test_Otot(cosmo)  # NOT b/c abstract `w(z)`
-        assert np.allclose(
-            cosmo.Otot(z),
-            cosmo.Om(z) + cosmo.Ogamma(z) + cosmo.Onu(z) + cosmo.Ode(z) + cosmo.Ok(z))
-
-    # ---------------------------------------------------------------
-
-    def test_efunc_vs_invefunc(self, cosmo):
-        """Test that ``efunc`` and ``inv_efunc`` give inverse values.
-
-        Note that the test doesn't need scipy because it doesn't need to call
-        ``de_density_scale``.
-        """
-        # super().test_efunc_vs_invefunc(cosmo)  # NOT b/c abstract `w(z)`
-        z0 = 0.5
-        z = np.array([0.5, 1.0, 2.0, 5.0])
-
-        assert np.allclose(cosmo.efunc(z0), 1.0 / cosmo.inv_efunc(z0))
-        assert np.allclose(cosmo.efunc(z), 1.0 / cosmo.inv_efunc(z))
+    @pytest.mark.skipif(not HAS_SCIPY, reason="scipy required for this test.")
+    @pytest.mark.parametrize(
+        ("args", "kwargs", "expected"),
+        [((70, 0.27, 0.73), {"Tcmb0": 3.0, "Ob0": 0.03}, None)],
+    )
+    def test_comoving_distance_example(self, cosmo_cls, args, kwargs, expected):
+        with pytest.raises(NotImplementedError):
+            super().test_comoving_distance_example(cosmo_cls, args, kwargs, expected)
 
 
 # -----------------------------------------------------------------------------
 
+
 class ParameterFlatOde0TestMixin(ParameterOde0TestMixin):
     """Tests for `astropy.cosmology.Parameter` Ode0 on a flat Cosmology.
 
@@ -823,7 +966,8 @@ class ParameterFlatOde0TestMixin(ParameterOde0TestMixin):
     def test_Parameter_Ode0(self, cosmo_cls):
         """Test Parameter ``Ode0`` on the class."""
         super().test_Parameter_Ode0(cosmo_cls)
-        assert cosmo_cls.Ode0.derived in (True, np.True_)
+        Ode0 = cosmo_cls.parameters.get("Ode0", cosmo_cls._derived_parameters["Ode0"])
+        assert Ode0.derived in (True, np.True_)
 
     def test_Ode0(self, cosmo):
         """Test no-longer-Parameter ``Ode0``."""
@@ -885,7 +1029,9 @@ class FlatFLRWMixinTest(FlatCosmologyMixinTest, ParameterFlatOde0TestMixin):
 
         cosmo = cosmo_cls(*self.cls_args, **self.cls_kwargs)
         assert cosmo._Ok0 == 0.0
-        assert cosmo._Ode0 == 1.0 - (cosmo._Om0 + cosmo._Ogamma0 + cosmo._Onu0 + cosmo._Ok0)
+        assert cosmo._Ode0 == 1.0 - (
+            cosmo._Om0 + cosmo._Ogamma0 + cosmo._Onu0 + cosmo._Ok0
+        )
 
     def test_Ok0(self, cosmo_cls, cosmo):
         """Test property ``Ok0``."""
@@ -911,7 +1057,9 @@ class FlatFLRWMixinTest(FlatCosmologyMixinTest, ParameterFlatOde0TestMixin):
 
     @pytest.mark.skipif(not HAS_SCIPY, reason="scipy is not installed")
     @pytest.mark.parametrize("z, exc", invalid_zs)
-    @pytest.mark.parametrize('method', FLRWSubclassTest._FLRW_redshift_methods - {"Otot"})
+    @pytest.mark.parametrize(
+        "method", sorted(FLRWTest._FLRW_redshift_methods - {"Otot"})
+    )
     def test_redshift_method_bad_input(self, cosmo, method, z, exc):
         """Test all the redshift methods for bad input."""
         super().test_redshift_method_bad_input(cosmo, method, z, exc)
@@ -928,7 +1076,7 @@ class FlatFLRWMixinTest(FlatCosmologyMixinTest, ParameterFlatOde0TestMixin):
 
         # change to non-flat
         nc = cosmo.clone(to_nonflat=True, Ode0=cosmo.Ode0)
-        assert isinstance(nc, cosmo._nonflat_cls_)
+        assert isinstance(nc, cosmo.__nonflatclass__)
         assert nc == cosmo.nonflat
 
         nc = cosmo.clone(to_nonflat=True, Ode0=1)
@@ -946,7 +1094,7 @@ class FlatFLRWMixinTest(FlatCosmologyMixinTest, ParameterFlatOde0TestMixin):
         assert not nonflatcosmo.is_equivalent(cosmo)
 
         # non-flat version of class
-        nonflat_cosmo_cls = cosmo.__class__.mro()[3]
+        nonflat_cosmo_cls = cosmo.__nonflatclass__
         # keys check in `test_is_equivalent_nonflat_class_different_params`
 
         # non-flat
@@ -955,20 +1103,22 @@ class FlatFLRWMixinTest(FlatCosmologyMixinTest, ParameterFlatOde0TestMixin):
         assert not cosmo.is_equivalent(nonflat)
 
         # flat, but not FlatFLRWMixin
-        flat = nonflat_cosmo_cls(*self.cls_args,
-                                 Ode0=1.0 - cosmo.Om0 - cosmo.Ogamma0 - cosmo.Onu0,
-                                 **self.cls_kwargs)
+        flat = nonflat_cosmo_cls(
+            *self.cls_args,
+            Ode0=1.0 - cosmo.Om0 - cosmo.Ogamma0 - cosmo.Onu0,
+            **self.cls_kwargs,
+        )
         flat._Ok0 = 0.0
         assert flat.is_equivalent(cosmo)
         assert cosmo.is_equivalent(flat)
 
-    def test_repr(self, cosmo_cls, cosmo):
+    def test_repr(self, cosmo):
         """
         Test method ``.__repr__()``. Skip non-flat superclass test.
         e.g. `TestFlatLambdaCDDM` -> `FlatFLRWMixinTest`
         vs   `TestFlatLambdaCDDM` -> `TestLambdaCDDM` -> `FlatFLRWMixinTest`
         """
-        FLRWSubclassTest.test_repr(self, cosmo_cls, cosmo)
+        FLRWTest.test_repr(self, cosmo)
 
         # test eliminated Ode0 from parameters
         assert "Ode0" not in repr(cosmo)
