@@ -84,8 +84,7 @@ def find_latex_line(lines, latex):
     for i, line in enumerate(lines):
         if re_string.match(line):
             return i
-    else:
-        return None
+    return None
 
 
 class LatexInputter(core.BaseInputter):
@@ -109,15 +108,12 @@ class LatexSplitter(core.BaseSplitter):
         """Remove whitespace at the beginning or end of line. Also remove
         \\ at end of line.
         """
-        line = RE_COMMENT.split(line)[0]
-        line = line.strip()
-        if line.endswith(r"\\"):
-            line = line.rstrip(r"\\")
-        else:
+        line = RE_COMMENT.split(line)[0].strip()
+        if not line.endswith(r"\\"):
             raise core.InconsistentTableError(
                 r"Lines in LaTeX table have to end with \\"
             )
-        return line
+        return line.removesuffix(r"\\")
 
     def process_val(self, val):
         """Remove whitespace and {} at the beginning or end of value."""
@@ -248,8 +244,8 @@ class Latex(core.BaseReader):
             The default is ``\\begin{table}``.  The following would generate a table,
             which spans the whole page in a two-column document::
 
-                ascii.write(data, sys.stdout, Writer = ascii.Latex,
-                            latexdict = {'tabletype': 'table*'})
+                ascii.write(data, sys.stdout, format="latex",
+                            latexdict={'tabletype': 'table*'})
 
             If ``None``, the table environment will be dropped, keeping only
             the ``tabular`` environment.
@@ -280,8 +276,8 @@ class Latex(core.BaseReader):
 
               from astropy.io import ascii
               data = {'name': ['bike', 'car'], 'mass': [75,1200], 'speed': [10, 130]}
-              ascii.write(data, Writer=ascii.Latex,
-                               latexdict = {'units': {'mass': 'kg', 'speed': 'km/h'}})
+              ascii.write(data, format="latex",
+                          latexdict={'units': {'mass': 'kg', 'speed': 'km/h'}})
 
             If the column has no entry in the ``units`` dictionary, it defaults
             to the **unit** attribute of the column. If this attribute is not
@@ -292,18 +288,18 @@ class Latex(core.BaseReader):
 
             from astropy.io import ascii
             data = {'cola': [1,2], 'colb': [3,4]}
-            ascii.write(data, Writer=ascii.Latex, latexdict=ascii.latex.latexdicts['template'])
+            ascii.write(data, format="latex", latexdict=ascii.latex.latexdicts['template'])
 
         Some table styles are predefined in the dictionary
         ``ascii.latex.latexdicts``. The following generates in table in
         style preferred by A&A and some other journals::
 
-            ascii.write(data, Writer=ascii.Latex, latexdict=ascii.latex.latexdicts['AA'])
+            ascii.write(data, format="latex", latexdict=ascii.latex.latexdicts['AA'])
 
         As an example, this generates a table, which spans all columns
         and is centered on the page::
 
-            ascii.write(data, Writer=ascii.Latex, col_align='|lr|',
+            ascii.write(data, format="latex", col_align='|lr|',
                         latexdict={'preamble': r'\begin{center}',
                                    'tablefoot': r'\end{center}',
                                    'tabletype': 'table*'})
