@@ -13,7 +13,7 @@ import pytest
 from astropy import units as u
 from astropy.coordinates import SkyCoord
 from astropy.io import ascii
-from astropy.table import Column, MaskedColumn, Table
+from astropy.table import Column, MaskedColumn, QTable, Table
 from astropy.time import Time
 from astropy.utils.data import get_pkg_data_filename
 from astropy.utils.exceptions import AstropyWarning
@@ -192,9 +192,9 @@ def test_write_byte_by_byte_for_masked_column():
     assert lines == exp_output
 
 
-exp_coord_cols_output = dict(
+exp_coord_cols_output = {
     # fmt: off
-    generic=[
+    "generic": [
         '================================================================================',
         'Byte-by-byte Description of file: table.dat',
         '--------------------------------------------------------------------------------',
@@ -220,7 +220,7 @@ exp_coord_cols_output = dict(
         'HD81809  1e-07  22.25608   2e+00  67 5.0 20 22 02 15.4500000000 -61 39 34.599996000',
         'HD103095 -3e+06 27.25000  -9e+34 -30 5.0 20 12 48 15.2244072000 +17 46 26.496624000',
     ],
-    positive_de=[
+    "positive_de": [
         '================================================================================',
         'Byte-by-byte Description of file: table.dat',
         '--------------------------------------------------------------------------------',
@@ -247,7 +247,7 @@ exp_coord_cols_output = dict(
         'HD103095 -3e+06 27.25000  -9e+34 -30 5.0 20 12 48 15.2244072000 +17 46 26.496624000',
     ],
     # fmt: on
-    galactic=[
+    "galactic": [
         "================================================================================",
         "Byte-by-byte Description of file: table.dat",
         "--------------------------------------------------------------------------------",
@@ -268,7 +268,7 @@ exp_coord_cols_output = dict(
         "HD81809  1e-07  22.25608   2e+00  67 5.0 20 330.071639591690 -45.548080484609",
         "HD103095 -3e+06 27.25000  -9e+34 -30 5.0 20 330.071639591690 -45.548080484609",
     ],
-    ecliptic=[
+    "ecliptic": [
         "================================================================================",
         "Byte-by-byte Description of file: table.dat",
         "--------------------------------------------------------------------------------",
@@ -289,7 +289,7 @@ exp_coord_cols_output = dict(
         "HD81809  1e-07  22.25608   2e+00  67 5.0 20 306.224208650096 -45.621789850825",
         "HD103095 -3e+06 27.25000  -9e+34 -30 5.0 20 306.224208650096 -45.621789850825",
     ],
-)
+}
 
 
 def test_write_coord_cols():
@@ -403,8 +403,8 @@ Byte-by-byte Description of file: table.dat
     t.remove_columns(["s", "i"])
     description = (
         "This is a tediously long description."
-        + " But they do sometimes have them."
-        + " Better to put extra details in the notes. "
+        " But they do sometimes have them."
+        " Better to put extra details in the notes. "
     )
     t["names"].description = description * 2
     t["names"].name = "thisIsALongColumnLabel"
@@ -425,21 +425,22 @@ def test_write_mixin_and_broken_cols():
     """
     # fmt: off
     exp_output = [
-        '================================================================================',
-        'Byte-by-byte Description of file: table.dat',
-        '--------------------------------------------------------------------------------',
-        ' Bytes Format Units  Label     Explanations',
-        '--------------------------------------------------------------------------------',
-        '  1-  7  A7     ---    name    Description of name   ',
-        '  9- 74  A66    ---    Unknown Description of Unknown',
-        ' 76-114  A39    ---    Unknown Description of Unknown',
-        '116-138  A23    ---    Unknown Description of Unknown',
-        '--------------------------------------------------------------------------------',
-        'Notes:',
-        '--------------------------------------------------------------------------------',
-        'HD81809 <SkyCoord (ICRS): (ra, dec) in deg',
-        '    (330.564375, -61.65961111)> (0.41342785, -0.23329341, -0.88014294)  2019-01-01 00:00:00.000',
-        'random  12                                                                 (0.41342785, -0.23329341, -0.88014294)  2019-01-01 00:00:00.000',
+        "================================================================================",
+        "Byte-by-byte Description of file: table.dat",
+        "--------------------------------------------------------------------------------",
+        " Bytes Format Units  Label     Explanations",
+        "--------------------------------------------------------------------------------",
+        "  1-  7  A7     ---    name    Description of name       ",
+        "  9- 74  A66    ---    Unknown Description of Unknown    ",
+        " 76-114  A39    ---    cart    Description of cart       ",
+        "116-138  A23    ---    time    Description of time       ",
+        "140-142  F3.1   m      q       [1.0/1.0] Description of q",
+        "--------------------------------------------------------------------------------",
+        "Notes:",
+        "--------------------------------------------------------------------------------",
+        "HD81809 <SkyCoord (ICRS): (ra, dec) in deg",
+        "    (330.564375, -61.65961111)> (0.41342785, -0.23329341, -0.88014294)  2019-01-01 00:00:00.000 1.0",
+        "random  12                                                                 (0.41342785, -0.23329341, -0.88014294)  2019-01-01 00:00:00.000 1.0",
     ]
     # fmt: on
     t = Table()
@@ -449,6 +450,7 @@ def test_write_mixin_and_broken_cols():
     t.add_row(["random", 12])
     t["cart"] = coord.cartesian
     t["time"] = Time("2019-1-1")
+    t["q"] = u.Quantity(1.0, u.m)
     out = StringIO()
     t.write(out, format="ascii.mrt")
     lines = out.getvalue().splitlines()
@@ -552,3 +554,13 @@ def test_write_skycoord_with_format():
     lines = lines[i_bbb:]  # Select Byte-By-Byte section and following lines.
     # Check the written table.
     assert lines == exp_output
+
+
+def test_write_qtable():
+    # Regression test for gh-12804
+    qt = QTable([np.arange(4) * u.m, ["a", "b", "c", "ddd"]], names=["a", "b"])
+    out = StringIO()
+    qt.write(out, format="mrt")
+    result = out.getvalue()
+    assert "Description of a" in result
+    assert "Description of b" in result
