@@ -178,7 +178,7 @@ class Card(_Verify):
         # card
         self._hierarch = False
 
-        # If the card could not be parsed according the the FITS standard or
+        # If the card could not be parsed according the FITS standard or
         # any recognized non-standard conventions, this will be True
         self._invalid = False
 
@@ -269,9 +269,9 @@ class Card(_Verify):
                     # We'll gladly create a HIERARCH card, but a warning is
                     # also displayed
                     warnings.warn(
-                        "Keyword name {!r} is greater than 8 characters or "
+                        f"Keyword name {keyword!r} is greater than 8 characters or "
                         "contains characters not allowed by the FITS "
-                        "standard; a HIERARCH card will be created.".format(keyword),
+                        "standard; a HIERARCH card will be created.",
                         VerifyWarning,
                     )
             else:
@@ -354,8 +354,8 @@ class Card(_Verify):
             if not m:
                 raise ValueError(
                     "FITS header values must contain standard printable ASCII "
-                    "characters; {!r} contains characters not representable in "
-                    "ASCII or non-printable characters.".format(value)
+                    f"characters; {value!r} contains characters not representable in "
+                    "ASCII or non-printable characters."
                 )
         elif isinstance(value, np.bool_):
             value = bool(value)
@@ -508,7 +508,7 @@ class Card(_Verify):
             self._field_specifier = field_specifier
             # The keyword need also be updated
             keyword = self._keyword.split(".", 1)[0]
-            self._keyword = ".".join([keyword, field_specifier])
+            self._keyword = f"{keyword}.{field_specifier}"
             self._modified = True
 
     @field_specifier.deleter
@@ -697,7 +697,7 @@ class Card(_Verify):
         attributes if the card was determined to be a RVKC.
         """
         keyword_upper = keyword.upper()
-        self._keyword = ".".join((keyword_upper, field_specifier))
+        self._keyword = f"{keyword_upper}.{field_specifier}"
         self._rawkeyword = keyword_upper
         self._field_specifier = field_specifier
         self._value = _int_or_float(value)
@@ -742,7 +742,7 @@ class Card(_Verify):
             else:
                 warnings.warn(
                     "The following header keyword is invalid or follows an "
-                    "unrecognized non-standard convention:\n{}".format(self._image),
+                    f"unrecognized non-standard convention:\n{self._image}",
                     AstropyUserWarning,
                 )
                 self._invalid = True
@@ -897,7 +897,7 @@ class Card(_Verify):
     def _fix_keyword(self):
         if self.field_specifier:
             keyword, field_specifier = self._keyword.split(".", 1)
-            self._keyword = ".".join([keyword.upper(), field_specifier])
+            self._keyword = f"{keyword.upper()}.{field_specifier}"
         else:
             self._keyword = self._keyword.upper()
         self._modified = True
@@ -1010,7 +1010,7 @@ class Card(_Verify):
             delimiter = ""
 
         # put all parts together
-        output = "".join([keyword, delimiter, value, comment])
+        output = f"{keyword}{delimiter}{value}{comment}"
 
         # For HIERARCH cards we can save a bit of space if necessary by
         # removing the space between the keyword and the equals sign; I'm
@@ -1123,14 +1123,14 @@ class Card(_Verify):
             and self._image.find("=") != 8
         ):
             errs.append(
-                dict(
-                    err_text=(
-                        "Card {!r} is not FITS standard (equal sign not "
-                        "at column 8).".format(self.keyword)
+                {
+                    "err_text": (
+                        f"Card {self.keyword!r} is not FITS standard (equal sign not "
+                        "at column 8)."
                     ),
-                    fix_text=fix_text,
-                    fix=self._fix_value,
-                )
+                    "fix_text": fix_text,
+                    "fix": self._fix_value,
+                }
             )
 
         # verify the key, it is never fixable
@@ -1146,11 +1146,11 @@ class Card(_Verify):
                 if keyword != keyword.upper():
                     # Keyword should be uppercase unless it's a HIERARCH card
                     errs.append(
-                        dict(
-                            err_text=f"Card keyword {keyword!r} is not upper case.",
-                            fix_text=fix_text,
-                            fix=self._fix_keyword,
-                        )
+                        {
+                            "err_text": f"Card keyword {keyword!r} is not upper case.",
+                            "fix_text": fix_text,
+                            "fix": self._fix_keyword,
+                        }
                     )
 
             keyword = self.keyword
@@ -1159,7 +1159,7 @@ class Card(_Verify):
 
             if not self._keywd_FSC_RE.match(keyword):
                 errs.append(
-                    dict(err_text=f"Illegal keyword name {keyword!r}", fixable=False)
+                    {"err_text": f"Illegal keyword name {keyword!r}", "fixable": False}
                 )
 
         # verify the value, it may be fixable
@@ -1169,13 +1169,13 @@ class Card(_Verify):
             # contains only printable ASCII characters
             if not self._ascii_text_re.match(valuecomment):
                 errs.append(
-                    dict(
-                        err_text=(
+                    {
+                        "err_text": (
                             f"Unprintable string {valuecomment!r}; commentary "
                             "cards may only contain printable ASCII characters"
                         ),
-                        fixable=False,
-                    )
+                        "fixable": False,
+                    }
                 )
         else:
             if not self._valuemodified:
@@ -1186,14 +1186,14 @@ class Card(_Verify):
                 # https://github.com/astropy/astropy/issues/5408
                 if m is None:
                     errs.append(
-                        dict(
-                            err_text=(
+                        {
+                            "err_text": (
                                 f"Card {self.keyword!r} is not FITS standard "
                                 f"(invalid value string: {valuecomment!r})."
                             ),
-                            fix_text=fix_text,
-                            fix=self._fix_value,
-                        )
+                            "fix_text": fix_text,
+                            "fix": self._fix_value,
+                        }
                     )
 
         # verify the comment (string), it is never fixable
@@ -1203,13 +1203,13 @@ class Card(_Verify):
             if comment is not None:
                 if not self._ascii_text_re.match(comment):
                     errs.append(
-                        dict(
-                            err_text=(
+                        {
+                            "err_text": (
                                 f"Unprintable string {comment!r}; header comments "
                                 "may only contain printable ASCII characters"
                             ),
-                            fixable=False,
-                        )
+                            "fixable": False,
+                        }
                     )
 
         errs = _ErrList([self.run_option(option, **err) for err in errs])
