@@ -1,10 +1,8 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-import abc
 import contextlib
 import re
 import warnings
-from collections import OrderedDict
 from operator import itemgetter
 
 import numpy as np
@@ -21,7 +19,7 @@ class IORegistryError(Exception):
 # -----------------------------------------------------------------------------
 
 
-class _UnifiedIORegistryBase(metaclass=abc.ABCMeta):
+class _UnifiedIORegistryBase:
     """Base class for registries in Astropy's Unified IO.
 
     This base class provides identification functions and miscellaneous
@@ -40,15 +38,18 @@ class _UnifiedIORegistryBase(metaclass=abc.ABCMeta):
 
     def __init__(self):
         # registry of identifier functions
-        self._identifiers = OrderedDict()
+        self._identifiers = {}
 
         # what this class can do: e.g. 'read' &/or 'write'
-        self._registries = dict()
-        self._registries["identify"] = dict(attr="_identifiers", column="Auto-identify")
+        self._registries = {}
+        self._registries["identify"] = {
+            "attr": "_identifiers",
+            "column": "Auto-identify",
+        }
         self._registries_order = ("identify",)  # match keys in `_registries`
 
         # If multiple formats are added to one class the update of the docs is quite
-        # expensive. Classes for which the doc update is temporarly delayed are added
+        # expensive. Classes for which the doc update is temporarily delayed are added
         # to this set.
         self._delayed_docs_classes = set()
 
@@ -252,7 +253,7 @@ class _UnifiedIORegistryBase(metaclass=abc.ABCMeta):
             register_identifier('ipac', Table, my_identifier)
             unregister_identifier('ipac', Table)
         """
-        if not (data_format, data_class) in self._identifiers or force:
+        if not (data_format, data_class) in self._identifiers or force:  # noqa: E713
             self._identifiers[(data_format, data_class)] = identifier
         else:
             raise IORegistryError(
@@ -262,7 +263,7 @@ class _UnifiedIORegistryBase(metaclass=abc.ABCMeta):
 
     def unregister_identifier(self, data_format, data_class):
         """
-        Unregister an identifier function
+        Unregister an identifier function.
 
         Parameters
         ----------
@@ -328,10 +329,10 @@ class _UnifiedIORegistryBase(metaclass=abc.ABCMeta):
         return format_table_str
 
     def _is_best_match(self, class1, class2, format_classes):
-        """
-        Determine if class2 is the "best" match for class1 in the list
-        of classes.  It is assumed that (class2 in classes) is True.
-        class2 is the the best match if:
+        """Determine if class2 is the "best" match for class1 in the list of classes.
+
+        It is assumed that (class2 in classes) is True.
+        class2 is the best match if:
 
         - ``class1`` is a subclass of ``class2`` AND
         - ``class2`` is the nearest ancestor of ``class1`` that is in classes
@@ -342,7 +343,7 @@ class _UnifiedIORegistryBase(metaclass=abc.ABCMeta):
             for parent in class1.__mro__:
                 if parent is class2:  # class2 is closest registered ancestor
                     return True
-                if parent in classes:  # class2 was superceded
+                if parent in classes:  # class2 was superseded
                     return False
         return False
 
