@@ -32,7 +32,6 @@ from importlib.metadata import entry_points
 import numpy as np
 
 from astropy.units import Quantity
-from astropy.utils.decorators import deprecated
 from astropy.utils.exceptions import AstropyUserWarning
 
 from .optimizers import DEFAULT_ACC, DEFAULT_EPS, DEFAULT_MAXITER, SLSQP, Simplex
@@ -323,14 +322,14 @@ class Fitter(metaclass=_FitterMeta):
             raise ValueError("Expected an optimizer.")
         if statistic is None:
             raise ValueError("Expected a statistic function.")
-        if inspect.isclass(optimizer):
+        if isinstance(optimizer, type):
             # a callable class
             self._opt_method = optimizer()
         elif inspect.isfunction(optimizer):
             self._opt_method = optimizer
         else:
             raise ValueError("Expected optimizer to be a callable class or a function.")
-        if inspect.isclass(statistic):
+        if isinstance(statistic, type):
             self._stat_method = statistic()
         else:
             self._stat_method = statistic
@@ -2057,14 +2056,6 @@ def fitter_to_model_params(model, fps, use_min_max_bounds=True):
                 model._array_to_parameters()
 
 
-@deprecated(
-    since="5.1",
-    message="private method: _fitter_to_model_params has been made public now",
-)
-def _fitter_to_model_params(model, fps):
-    return fitter_to_model_params(model, fps)
-
-
 def model_to_fit_params(model):
     """
     Convert a model instance's parameter array to an array that can be used
@@ -2104,14 +2095,6 @@ def model_to_fit_params(model):
     return model_params, fitparam_indices, model_bounds
 
 
-@deprecated(
-    since="5.1",
-    message="private method: _model_to_fit_params has been made public now",
-)
-def _model_to_fit_params(model):
-    return model_to_fit_params(model)
-
-
 def _validate_constraints(supported_constraints, model):
     """Make sure model constraints are supported by the current fitter."""
     message = "Optimizer cannot handle {0} constraints."
@@ -2184,7 +2167,7 @@ def populate_entry_points(entry_points):
                 )
             )
         else:
-            if not inspect.isclass(entry_point):
+            if not isinstance(entry_point, type):
                 warnings.warn(
                     AstropyUserWarning(
                         f"Modeling entry point {name} expected to be a Class."
@@ -2194,7 +2177,7 @@ def populate_entry_points(entry_points):
                 if issubclass(entry_point, Fitter):
                     name = entry_point.__name__
                     globals()[name] = entry_point
-                    __all__.append(name)
+                    __all__.append(name)  # noqa: PYI056
                 else:
                     warnings.warn(
                         AstropyUserWarning(
