@@ -3,6 +3,7 @@
 This module tests model set evaluation and fitting for some common use cases.
 """
 import numpy as np
+
 # pylint: disable=invalid-name
 import pytest
 from numpy.testing import assert_allclose
@@ -10,8 +11,17 @@ from numpy.testing import assert_allclose
 from astropy.modeling.core import Model
 from astropy.modeling.fitting import LinearLSQFitter
 from astropy.modeling.models import (
-    Chebyshev1D, Chebyshev2D, Hermite1D, Hermite2D, Legendre1D, Legendre2D, Linear1D, Planar2D,
-    Polynomial1D, Polynomial2D)
+    Chebyshev1D,
+    Chebyshev2D,
+    Hermite1D,
+    Hermite2D,
+    Legendre1D,
+    Legendre2D,
+    Linear1D,
+    Planar2D,
+    Polynomial1D,
+    Polynomial2D,
+)
 from astropy.modeling.parameters import Parameter
 from astropy.utils import NumpyRNGContext
 
@@ -26,9 +36,10 @@ class TParModel(Model):
     """
     A toy model to test parameters machinery
     """
+
     # standard_broadasting = False
     n_inputs = 1
-    outputs = ('x',)
+    outputs = ("x",)
     coeff = Parameter()
     e = Parameter()
 
@@ -37,10 +48,12 @@ class TParModel(Model):
 
     @staticmethod
     def evaluate(x, coeff, e):
-        return x*coeff + e
+        return x * coeff + e
 
 
-@pytest.mark.parametrize('model_class', [Polynomial1D, Chebyshev1D, Legendre1D, Hermite1D])
+@pytest.mark.parametrize(
+    "model_class", [Polynomial1D, Chebyshev1D, Legendre1D, Hermite1D]
+)
 def test_model1d_axis_1(model_class):
     """
     Test that a model initialized with model_set_axis=1
@@ -56,7 +69,8 @@ def test_model1d_axis_1(model_class):
 
     p1 = model_class(1, c0=c0, c1=c1, n_models=n_models, model_set_axis=model_axis)
 
-    with pytest.raises(ValueError):
+    MESSAGE = r"For model_set_axis=1, all inputs must be at least 2-dimensional"
+    with pytest.raises(ValueError, match=MESSAGE):
         p1(x)
 
     y = p1(x, model_set_axis=False)
@@ -75,22 +89,26 @@ def test_model1d_axis_1(model_class):
     assert_allclose(y[:, 1, :, :], t2(xxx))
 
 
-@pytest.mark.parametrize('model_class', [Polynomial1D, Chebyshev1D, Legendre1D, Hermite1D])
+@pytest.mark.parametrize(
+    "model_class", [Polynomial1D, Chebyshev1D, Legendre1D, Hermite1D]
+)
 def test_model1d_axis_2(model_class):
     """
     Test that a model initialized with model_set_axis=2
     can be evaluated with model_set_axis=False.
     """
-    p1 = model_class(1, c0=[[[1, 2, 3]]], c1=[[[10, 20, 30]]],
-                     n_models=3, model_set_axis=2)
+    p1 = model_class(
+        1, c0=[[[1, 2, 3]]], c1=[[[10, 20, 30]]], n_models=3, model_set_axis=2
+    )
     t1 = model_class(1, c0=1, c1=10)
     t2 = model_class(1, c0=2, c1=20)
     t3 = model_class(1, c0=3, c1=30)
 
-    with pytest.raises(ValueError):
+    MESSAGE = r"For model_set_axis=2, all inputs must be at least 3-dimensional"
+    with pytest.raises(ValueError, match=MESSAGE):
         p1(x)
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match=MESSAGE):
         p1(xx)
 
     y = p1(x, model_set_axis=False)
@@ -100,7 +118,9 @@ def test_model1d_axis_2(model_class):
     assert_allclose(y[:, :, 2].flatten(), t3(x))
 
 
-@pytest.mark.parametrize('model_class', [Polynomial1D, Chebyshev1D, Legendre1D, Hermite1D])
+@pytest.mark.parametrize(
+    "model_class", [Polynomial1D, Chebyshev1D, Legendre1D, Hermite1D]
+)
 def test_model1d_axis_0(model_class):
     """
     Test that a model initialized with model_set_axis=0
@@ -112,7 +132,8 @@ def test_model1d_axis_0(model_class):
     t1 = model_class(1, c0=2, c1=1)
     t2 = model_class(1, c0=3, c1=2)
 
-    with pytest.raises(ValueError):
+    MESSAGE = r"Input argument 'x' does not have the correct dimensions in .*"
+    with pytest.raises(ValueError, match=MESSAGE):
         p1(x)
 
     y = p1(xx)
@@ -135,14 +156,22 @@ def test_model1d_axis_0(model_class):
     assert len(y) == 2
 
 
-@pytest.mark.parametrize('model_class', [Chebyshev2D, Legendre2D, Hermite2D])
+@pytest.mark.parametrize("model_class", [Chebyshev2D, Legendre2D, Hermite2D])
 def test_model2d_axis_2(model_class):
     """
     Test that a model initialized with model_set_axis=2
     can be evaluated with model_set_axis=False.
     """
-    p2 = model_class(1, 1, c0_0=[[[0, 1, 2]]], c0_1=[[[3, 4, 5]]],
-                     c1_0=[[[5, 6, 7]]], c1_1=[[[1, 1, 1]]], n_models=3, model_set_axis=2)
+    p2 = model_class(
+        1,
+        1,
+        c0_0=[[[0, 1, 2]]],
+        c0_1=[[[3, 4, 5]]],
+        c1_0=[[[5, 6, 7]]],
+        c1_1=[[[1, 1, 1]]],
+        n_models=3,
+        model_set_axis=2,
+    )
     t1 = model_class(1, 1, c0_0=0, c0_1=3, c1_0=5, c1_1=1)
     t2 = model_class(1, 1, c0_0=1, c0_1=4, c1_0=6, c1_1=1)
     t3 = model_class(1, 1, c0_0=2, c0_1=5, c1_0=7, c1_1=1)
@@ -161,10 +190,11 @@ def test_negative_axis():
     t1 = Polynomial1D(1, c0=1, c1=3)
     t2 = Polynomial1D(1, c0=2, c1=4)
 
-    with pytest.raises(ValueError):
+    MESSAGE = r"Input argument 'x' does not have the correct dimensions in .*"
+    with pytest.raises(ValueError, match=MESSAGE):
         p1(x)
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match=MESSAGE):
         p1(xx)
 
     xxt = xx.T
@@ -210,14 +240,15 @@ def test_shapes():
 
 
 def test_eval():
-    """ Tests evaluation of Linear1D and Planar2D with different model_set_axis."""
+    """Tests evaluation of Linear1D and Planar2D with different model_set_axis."""
     model = Linear1D(slope=[1, 2], intercept=[3, 4], n_models=2)
     p = Polynomial1D(1, c0=[3, 4], c1=[1, 2], n_models=2)
 
     assert_allclose(model(xx), p(xx))
     assert_allclose(model(x, model_set_axis=False), p(x, model_set_axis=False))
 
-    with pytest.raises(ValueError):
+    MESSAGE = r"Input argument 'x' does not have the correct dimensions in .*"
+    with pytest.raises(ValueError, match=MESSAGE):
         model(x)
 
     model = Linear1D(slope=[[1, 2]], intercept=[[3, 4]], n_models=2, model_set_axis=1)
@@ -225,7 +256,7 @@ def test_eval():
 
     assert_allclose(model(xx.T), p(xx.T))
     assert_allclose(model(x, model_set_axis=False), p(x, model_set_axis=False))
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match=MESSAGE):
         model(xx)
 
     model = Planar2D(slope_x=[1, 2], slope_y=[1, 2], intercept=[3, 4], n_models=2)
@@ -233,14 +264,17 @@ def test_eval():
 
     assert y.shape == (2, 4)
 
-    with pytest.raises(ValueError):
+    MESSAGE = r"Missing input arguments - expected 2, got 1"
+    with pytest.raises(ValueError, match=MESSAGE):
         model(x)
 
 
 # Test fitting
 
 
-@pytest.mark.parametrize('model_class', [Polynomial1D, Chebyshev1D, Legendre1D, Hermite1D])
+@pytest.mark.parametrize(
+    "model_class", [Polynomial1D, Chebyshev1D, Legendre1D, Hermite1D]
+)
 def test_linearlsqfitter(model_class):
     """
     Issue #7159
@@ -248,7 +282,7 @@ def test_linearlsqfitter(model_class):
     p = model_class(1, n_models=2, model_set_axis=1)
 
     # Generate data for fitting 2 models and re-stack them along the last axis:
-    y = np.array([2*x+1, x+4])
+    y = np.array([2 * x + 1, x + 4])
     y = np.rollaxis(y, 0, -1).T
 
     f = LinearLSQFitter()
@@ -268,7 +302,7 @@ def test_linearlsqfitter(model_class):
 def test_model_set_axis_outputs():
     fitter = LinearLSQFitter()
     model_set = Polynomial2D(1, n_models=2, model_set_axis=2)
-    y2, x2 = np.mgrid[: 5, : 5]
+    y2, x2 = np.mgrid[:5, :5]
     # z = np.moveaxis([x2 + y2, 1 - 0.1 * x2 + 0.2 * y2]), 0, 2)
     z = np.rollaxis(np.array([x2 + y2, 1 - 0.1 * x2 + 0.2 * y2]), 0, 3)
     model = fitter(model_set, x2, y2, z)
@@ -277,25 +311,25 @@ def test_model_set_axis_outputs():
 
     # Test initializing with integer model_set_axis
     # and evaluating with a different model_set_axis
-    model_set = Polynomial1D(1, c0=[1, 2], c1=[2, 3],
-                             n_models=2, model_set_axis=0)
+    model_set = Polynomial1D(1, c0=[1, 2], c1=[2, 3], n_models=2, model_set_axis=0)
     y0 = model_set(xx)
     y1 = model_set(xx.T, model_set_axis=1)
     assert_allclose(y0[0], y1[:, 0])
     assert_allclose(y0[1], y1[:, 1])
 
-    model_set = Polynomial1D(1, c0=[[1, 2]], c1=[[2, 3]],
-                             n_models=2, model_set_axis=1)
+    model_set = Polynomial1D(1, c0=[[1, 2]], c1=[[2, 3]], n_models=2, model_set_axis=1)
     y0 = model_set(xx.T)
     y1 = model_set(xx, model_set_axis=0)
     assert_allclose(y0[:, 0], y1[0])
     assert_allclose(y0[:, 1], y1[1])
-    with pytest.raises(ValueError):
+
+    MESSAGE = r"For model_set_axis=1, all inputs must be at least 2-dimensional"
+    with pytest.raises(ValueError, match=MESSAGE):
         model_set(x)
 
 
 def test_fitting_shapes():
-    """ Test fitting model sets of Linear1D and Planar2D."""
+    """Test fitting model sets of Linear1D and Planar2D."""
     fitter = LinearLSQFitter()
 
     model = Linear1D(slope=[1, 2], intercept=[3, 4], n_models=2)
@@ -311,9 +345,12 @@ def test_fitting_shapes():
 
 
 def test_compound_model_sets():
-    with pytest.raises(ValueError):
-        (Polynomial1D(1, n_models=2, model_set_axis=1) |
-         Polynomial1D(1, n_models=2, model_set_axis=0))
+    MESSAGE = r"model_set_axis must be False or 0 and consistent for operands"
+    with pytest.raises(ValueError, match=MESSAGE):
+        (
+            Polynomial1D(1, n_models=2, model_set_axis=1)
+            | Polynomial1D(1, n_models=2, model_set_axis=0)
+        )
 
 
 def test_linear_fit_model_set_errors():
@@ -322,9 +359,11 @@ def test_linear_fit_model_set_errors():
     y = init_model(x, model_set_axis=False)
 
     fitter = LinearLSQFitter()
-    with pytest.raises(ValueError):
+
+    MESSAGE = r"x and y should have the same shape"
+    with pytest.raises(ValueError, match=MESSAGE):
         fitter(init_model, x[:5], y)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match=MESSAGE):
         fitter(init_model, x, y[:, :5])
 
 
@@ -344,15 +383,14 @@ def test_linear_fit_model_set_common_weight():
     weights = np.ones(10)
     weights[[0, -1]] = 0
     fitted_model = fitter(init_model, x, y, weights=weights)
-    assert_allclose(fitted_model(x, model_set_axis=False), y_expected,
-                    rtol=1e-1)
+    assert_allclose(fitted_model(x, model_set_axis=False), y_expected, rtol=1e-1)
 
     # Check that using null weights raises an error
     # ValueError: On entry to DLASCL parameter number 4 had an illegal value
-    with pytest.raises(ValueError,
-                       match='Found NaNs in the coefficient matrix'):
-        with pytest.warns(RuntimeWarning,
-                          match=r'invalid value encountered in.*divide'):
+    with pytest.raises(ValueError, match=r"Found NaNs in the coefficient matrix"):
+        with pytest.warns(
+            RuntimeWarning, match=r"invalid value encountered in.*divide"
+        ):
             fitted_model = fitter(init_model, x, y, weights=np.zeros(10))
 
 
@@ -374,108 +412,118 @@ def test_linear_fit_model_set_weights():
     weights[[0, 1], weights.argmax(axis=1)] = 0
     fitter = LinearLSQFitter()
     fitted_model = fitter(init_model, x, y, weights=weights)
-    assert_allclose(fitted_model(x, model_set_axis=False), y_expected,
-                    rtol=1e-1)
+    assert_allclose(fitted_model(x, model_set_axis=False), y_expected, rtol=1e-1)
 
     # Check that using null weights raises an error
     weights[0] = 0
-    with pytest.raises(ValueError,
-                       match='Found NaNs in the coefficient matrix'):
-        with pytest.warns(RuntimeWarning,
-                          match=r'invalid value encountered in.*divide'):
+    with pytest.raises(ValueError, match=r"Found NaNs in the coefficient matrix"):
+        with pytest.warns(
+            RuntimeWarning, match=r"invalid value encountered in.*divide"
+        ):
             fitted_model = fitter(init_model, x, y, weights=weights)
 
     # Now we mask the values where weight is 0
-    with pytest.warns(RuntimeWarning,
-                      match=r'invalid value encountered in.*divide'):
-        fitted_model = fitter(init_model, x,
-                              np.ma.array(y, mask=np.isclose(weights, 0)),
-                              weights=weights)
+    with pytest.warns(RuntimeWarning, match=r"invalid value encountered in.*divide"):
+        fitted_model = fitter(
+            init_model, x, np.ma.array(y, mask=np.isclose(weights, 0)), weights=weights
+        )
     # Parameters for the first model are all NaNs
     assert np.all(np.isnan(fitted_model.param_sets[:, 0]))
     assert np.all(np.isnan(fitted_model(x, model_set_axis=False)[0]))
     # Second model is fitted correctly
-    assert_allclose(fitted_model(x, model_set_axis=False)[1], y_expected[1],
-                    rtol=1e-1)
+    assert_allclose(fitted_model(x, model_set_axis=False)[1], y_expected[1], rtol=1e-1)
 
 
 def test_linear_fit_2d_model_set_errors():
-
     init_model = Polynomial2D(degree=2, c0_0=[1, 1], n_models=2)
     x = np.arange(10)
     y = np.arange(10)
     z = init_model(x, y, model_set_axis=False)
 
     fitter = LinearLSQFitter()
-    with pytest.raises(ValueError):
+
+    MESSAGE = r"x, y and z should have the same shape"
+    with pytest.raises(ValueError, match=MESSAGE):
         fitter(init_model, x[:5], y, z)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match=MESSAGE):
         fitter(init_model, x, y, z[:, :5])
 
 
 def test_linear_fit_2d_model_set_common_weight():
-    init_model = Polynomial2D(degree=2, c1_0=[1, 2], c0_1=[-0.5, 1],
-                              n_models=2,
-                              fixed={'c1_0': True, 'c0_1': True})
+    init_model = Polynomial2D(
+        degree=2,
+        c1_0=[1, 2],
+        c0_1=[-0.5, 1],
+        n_models=2,
+        fixed={"c1_0": True, "c0_1": True},
+    )
 
     x, y = np.mgrid[0:5, 0:5]
-    zz = np.array([1+x-0.5*y+0.1*x*x, 2*x+y-0.2*y*y])
+    zz = np.array([1 + x - 0.5 * y + 0.1 * x * x, 2 * x + y - 0.2 * y * y])
 
     fitter = LinearLSQFitter()
     fitted_model = fitter(init_model, x, y, zz, weights=np.ones((5, 5)))
 
-    assert_allclose(fitted_model(x, y, model_set_axis=False), zz,
-                    atol=1e-14)
+    assert_allclose(fitted_model(x, y, model_set_axis=False), zz, atol=1e-14)
 
 
 def test_linear_fit_flat_2d_model_set_common_weight():
-    init_model = Polynomial2D(degree=2, c1_0=[1, 2], c0_1=[-0.5, 1],
-                              n_models=2,
-                              fixed={'c1_0': True, 'c0_1': True})
+    init_model = Polynomial2D(
+        degree=2,
+        c1_0=[1, 2],
+        c0_1=[-0.5, 1],
+        n_models=2,
+        fixed={"c1_0": True, "c0_1": True},
+    )
 
     x, y = np.mgrid[0:5, 0:5]
     x, y = x.flatten(), y.flatten()
-    zz = np.array([1+x-0.5*y+0.1*x*x, 2*x+y-0.2*y*y])
+    zz = np.array([1 + x - 0.5 * y + 0.1 * x * x, 2 * x + y - 0.2 * y * y])
     weights = np.ones(25)
 
     fitter = LinearLSQFitter()
     fitted_model = fitter(init_model, x, y, zz, weights=weights)
 
-    assert_allclose(fitted_model(x, y, model_set_axis=False), zz,
-                    atol=1e-14)
+    assert_allclose(fitted_model(x, y, model_set_axis=False), zz, atol=1e-14)
 
 
 def test_linear_fit_2d_model_set_weights():
-    init_model = Polynomial2D(degree=2, c1_0=[1, 2], c0_1=[-0.5, 1],
-                              n_models=2,
-                              fixed={'c1_0': True, 'c0_1': True})
+    init_model = Polynomial2D(
+        degree=2,
+        c1_0=[1, 2],
+        c0_1=[-0.5, 1],
+        n_models=2,
+        fixed={"c1_0": True, "c0_1": True},
+    )
 
     x, y = np.mgrid[0:5, 0:5]
-    zz = np.array([1+x-0.5*y+0.1*x*x, 2*x+y-0.2*y*y])
+    zz = np.array([1 + x - 0.5 * y + 0.1 * x * x, 2 * x + y - 0.2 * y * y])
 
     fitter = LinearLSQFitter()
     weights = [np.ones((5, 5)), np.ones((5, 5))]
     fitted_model = fitter(init_model, x, y, zz, weights=weights)
 
-    assert_allclose(fitted_model(x, y, model_set_axis=False), zz,
-                    atol=1e-14)
+    assert_allclose(fitted_model(x, y, model_set_axis=False), zz, atol=1e-14)
 
 
 def test_linear_fit_flat_2d_model_set_weights():
-    init_model = Polynomial2D(degree=2, c1_0=[1, 2], c0_1=[-0.5, 1],
-                              n_models=2,
-                              fixed={'c1_0': True, 'c0_1': True})
+    init_model = Polynomial2D(
+        degree=2,
+        c1_0=[1, 2],
+        c0_1=[-0.5, 1],
+        n_models=2,
+        fixed={"c1_0": True, "c0_1": True},
+    )
 
     x, y = np.mgrid[0:5, 0:5]
     x, y = x.flatten(), y.flatten()
-    zz = np.array([1+x-0.5*y+0.1*x*x, 2*x+y-0.2*y*y])
+    zz = np.array([1 + x - 0.5 * y + 0.1 * x * x, 2 * x + y - 0.2 * y * y])
     weights = np.ones((2, 25))
 
     fitter = LinearLSQFitter()
     fitted_model = fitter(init_model, x, y, zz, weights=weights)
 
-    assert_allclose(fitted_model(x, y, model_set_axis=False), zz,
-                    atol=1e-14)
+    assert_allclose(fitted_model(x, y, model_set_axis=False), zz, atol=1e-14)
 
 
 class Test1ModelSet:
@@ -489,15 +537,15 @@ class Test1ModelSet:
 
     def setup_class(self):
         self.x1 = np.arange(0, 10)
-        self.y1 = np.array([0.5 + 2.5*self.x1])
+        self.y1 = np.array([0.5 + 2.5 * self.x1])
         self.w1 = np.ones((10,))
-        self.y1[0, 8] = 100.
-        self.w1[8] = 0.
+        self.y1[0, 8] = 100.0
+        self.w1[8] = 0.0
         self.y2, self.x2 = np.mgrid[0:10, 0:10]
-        self.z2 = np.array([1 - 0.1*self.x2 + 0.2*self.y2])
+        self.z2 = np.array([1 - 0.1 * self.x2 + 0.2 * self.y2])
         self.w2 = np.ones((10, 10))
-        self.z2[0, 1, 2] = 100.
-        self.w2[1, 2] = 0.
+        self.z2[0, 1, 2] = 100.0
+        self.w2[1, 2] = 0.0
 
     def test_linear_1d_common_weights(self):
         model = Polynomial1D(1)
@@ -509,16 +557,14 @@ class Test1ModelSet:
     def test_linear_1d_separate_weights(self):
         model = Polynomial1D(1)
         fitter = LinearLSQFitter()
-        model = fitter(model, self.x1, self.y1,
-                       weights=self.w1[np.newaxis, ...])
+        model = fitter(model, self.x1, self.y1, weights=self.w1[np.newaxis, ...])
         assert_allclose(model.c0, 0.5, atol=1e-12)
         assert_allclose(model.c1, 2.5, atol=1e-12)
 
     def test_linear_1d_separate_weights_axis_1(self):
         model = Polynomial1D(1, model_set_axis=1)
         fitter = LinearLSQFitter()
-        model = fitter(model, self.x1, self.y1.T,
-                       weights=self.w1[..., np.newaxis])
+        model = fitter(model, self.x1, self.y1.T, weights=self.w1[..., np.newaxis])
         assert_allclose(model.c0, 0.5, atol=1e-12)
         assert_allclose(model.c1, 2.5, atol=1e-12)
 
@@ -526,24 +572,30 @@ class Test1ModelSet:
         model = Polynomial2D(1)
         fitter = LinearLSQFitter()
         model = fitter(model, self.x2, self.y2, self.z2, weights=self.w2)
-        assert_allclose(model.c0_0, 1., atol=1e-12)
+        assert_allclose(model.c0_0, 1.0, atol=1e-12)
         assert_allclose(model.c1_0, -0.1, atol=1e-12)
         assert_allclose(model.c0_1, 0.2, atol=1e-12)
 
     def test_linear_2d_separate_weights(self):
         model = Polynomial2D(1)
         fitter = LinearLSQFitter()
-        model = fitter(model, self.x2, self.y2, self.z2,
-                       weights=self.w2[np.newaxis, ...])
-        assert_allclose(model.c0_0, 1., atol=1e-12)
+        model = fitter(
+            model, self.x2, self.y2, self.z2, weights=self.w2[np.newaxis, ...]
+        )
+        assert_allclose(model.c0_0, 1.0, atol=1e-12)
         assert_allclose(model.c1_0, -0.1, atol=1e-12)
         assert_allclose(model.c0_1, 0.2, atol=1e-12)
 
     def test_linear_2d_separate_weights_axis_2(self):
         model = Polynomial2D(1, model_set_axis=2)
         fitter = LinearLSQFitter()
-        model = fitter(model, self.x2, self.y2, np.rollaxis(self.z2, 0, 3),
-                       weights=self.w2[..., np.newaxis])
-        assert_allclose(model.c0_0, 1., atol=1e-12)
+        model = fitter(
+            model,
+            self.x2,
+            self.y2,
+            np.rollaxis(self.z2, 0, 3),
+            weights=self.w2[..., np.newaxis],
+        )
+        assert_allclose(model.c0_0, 1.0, atol=1e-12)
         assert_allclose(model.c1_0, -0.1, atol=1e-12)
         assert_allclose(model.c0_1, 0.2, atol=1e-12)
