@@ -14,12 +14,12 @@ def setup_module(module):
 
 def test_SAMPHubServer():
     """Test that SAMPHub can be instantiated"""
-    SAMPHubServer(web_profile=False, mode='multiple', pool_size=1)
+    SAMPHubServer(web_profile=False, mode="multiple", pool_size=1)
 
 
 def test_SAMPHubServer_run():
     """Test that SAMPHub can be run"""
-    hub = SAMPHubServer(web_profile=False, mode='multiple', pool_size=1)
+    hub = SAMPHubServer(web_profile=False, mode="multiple", pool_size=1)
     hub.start()
     time.sleep(1)
     hub.stop()
@@ -32,7 +32,7 @@ def test_SAMPHubServer_run_repeated():
     when web profile support is enabled.
     """
 
-    hub = SAMPHubServer(web_profile=True, mode='multiple', pool_size=1)
+    hub = SAMPHubServer(web_profile=True, mode="multiple", pool_size=1)
     hub.start()
     time.sleep(1)
     hub.stop()
