@@ -229,7 +229,7 @@ class Index:
             rows.append(row)
         # second pass - row order is reversed to maintain
         # correct row numbers
-        for row in reversed(sorted(rows)):
+        for row in sorted(rows, reverse=True):
             self.data.shift_left(row)
 
     def remove_row(self, row, reorder=True):
@@ -674,8 +674,7 @@ def get_index_by_names(table, names):
         index_names = [col.info.name for col in index.columns]
         if index_names == names:
             return index
-    else:
-        return None
+    return None
 
 
 class _IndexModeContext:
@@ -717,7 +716,7 @@ class _IndexModeContext:
             raise ValueError(
                 "Expected a mode of either 'freeze', "
                 "'discard_on_copy', or 'copy_on_getitem', got "
-                "'{}'".format(mode)
+                f"'{mode}'"
             )
 
     def __enter__(self):
