@@ -1,7 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-import pytest
 import numpy as np
+import pytest
 
 from astropy.table.sorted_array import SortedArray
 from astropy.table.table import Table
@@ -11,17 +11,17 @@ from astropy.table.table import Table
 def array():
     # composite index
     col0 = np.array([x % 2 for x in range(1, 11)])
-    col1 = np.array([x for x in range(1, 11)])
+    col1 = np.array(list(range(1, 11)))
     t = Table([col0, col1])
     t = t[t.argsort()]
-    return SortedArray(t, t['col1'].copy())
+    return SortedArray(t, t["col1"].copy())
 
 
 @pytest.fixture
 def wide_array():
     # array with 100 columns
     t = Table([[x] * 10 for x in np.arange(100)])
-    return SortedArray(t, t['col0'].copy())
+    return SortedArray(t, t["col0"].copy())
 
 
 def test_array_find(array):
