@@ -57,14 +57,13 @@ class TestRunnerBase:
     defining 'keyword' methods. These are methods that have the
     :class:`~astropy.tests.runner.keyword` decorator, these methods are used to
     construct allowed keyword arguments to the
-    ``run_tests`` method as a way to allow
+    `~astropy.tests.runner.TestRunnerBase.run_tests` method as a way to allow
     customization of individual keyword arguments (and associated logic)
     without having to re-implement the whole
-    ``run_tests`` method.
+    `~astropy.tests.runner.TestRunnerBase.run_tests` method.
 
     Examples
     --------
-
     A simple keyword method::
 
         class MyRunner(TestRunnerBase):
@@ -176,7 +175,7 @@ class TestRunnerBase:
         "pytest_astropy_header",
     ]
     _missing_dependancy_error = (
-        "Test dependencies are missing: {module}. You should install the "
+        "Test dependencies are missing: {}. You should install the "
         "'pytest-astropy' package (you may need to update the package if you "
         "have a previous version installed, e.g., "
         "'pip install pytest-astropy --upgrade' or the equivalent with conda)."
@@ -184,13 +183,21 @@ class TestRunnerBase:
 
     @classmethod
     def _has_test_dependencies(cls):  # pragma: no cover
-        # Using the test runner will not work without these dependencies, but
-        # pytest-openfiles is optional, so it's not listed here.
+        # Using the test runner will not work without these dependencies.
         for module in cls._required_dependencies:
             spec = find_spec(module)
-            # Checking loader accounts for packages that were uninstalled
+            # Checking loader accounts for packages that were uninstalled.
+            # pytest plugins are special, it's enough if they are picked up the
+            # pytest independently of how they are installed.
             if spec is None or spec.loader is None:
-                raise RuntimeError(cls._missing_dependancy_error.format(module=module))
+                # Don't import pytest until it's actually needed
+                import pytest
+
+                pluginmanager = pytest.PytestPluginManager()
+                try:
+                    pluginmanager.import_plugin(module)
+                except ImportError:
+                    raise RuntimeError(cls._missing_dependancy_error.format(module))
 
     def run_tests(self, **kwargs):
         # The following option will include eggs inside a .eggs folder in
@@ -252,13 +259,12 @@ class TestRunnerBase:
         """
         Constructs a `TestRunner` to run in the given path, and returns a
         ``test()`` function which takes the same arguments as
-        ``TestRunner.run_tests``.
+        `~astropy.tests.runner.TestRunner.run_tests`.
 
         The returned ``test()`` function will be defined in the module this
         was called from.  This is used to implement the ``astropy.test()``
         function (or the equivalent for affiliated packages).
         """
-
         runner = cls(path)
 
         @wraps(runner.run_tests, ("__doc__",))
@@ -284,7 +290,7 @@ class TestRunnerBase:
 
 class TestRunner(TestRunnerBase):
     """
-    A test runner for astropy tests
+    A test runner for astropy tests.
     """
 
     def packages_path(self, packages, base_path, error=None, warning=None):
@@ -470,7 +476,6 @@ class TestRunner(TestRunnerBase):
             data from http://data.astropy.org (``astropy``), or all tests that
             use remote data (``any``). The default is ``none``.
         """
-
         if remote_data is True:
             remote_data = "any"
         elif remote_data is False:
@@ -519,35 +524,6 @@ class TestRunner(TestRunnerBase):
             return ["--pdb"]
         return []
 
-    @keyword()
-    def open_files(self, open_files, kwargs):
-        """
-        open_files : bool, optional
-            Fail when any tests leave files open.  Off by default, because
-            this adds extra run time to the test suite.  Requires the
-            ``psutil`` package.
-        """
-        if open_files:
-            if kwargs["parallel"] != 0:
-                raise SystemError(
-                    "open file detection may not be used in conjunction with "
-                    "parallel testing."
-                )
-
-            try:
-                import psutil  # noqa: F401
-            except ImportError:
-                raise SystemError(
-                    "open file detection requested, but psutil package "
-                    "is not installed."
-                )
-
-            return ["--open-files"]
-
-            print("Checking for unclosed files")
-
-        return []
-
     @keyword(0)
     def parallel(self, parallel, kwargs):
         """
@@ -574,7 +550,6 @@ class TestRunner(TestRunnerBase):
         docs_path : str, optional
             The path to the documentation .rst files.
         """
-
         paths = []
         if docs_path is not None and not kwargs["skip_docs"]:
             if kwargs["package"] is not None:
