@@ -1,7 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
 import os
-from os.path import join
 
 import numpy
 from setuptools import Extension
@@ -12,9 +11,10 @@ BLS_ROOT = os.path.relpath(os.path.dirname(__file__))
 def get_extensions():
     ext = Extension(
         "astropy.timeseries.periodograms.bls._impl",
+        define_macros=[("NPY_NO_DEPRECATED_API", "NPY_1_7_API_VERSION")],
         sources=[
-            join(BLS_ROOT, "bls.c"),
-            join(BLS_ROOT, "_impl.pyx"),
+            os.path.join(BLS_ROOT, "bls.c"),
+            os.path.join(BLS_ROOT, "_impl.pyx"),
         ],
         include_dirs=[numpy.get_include()],
     )
