@@ -11,6 +11,7 @@ from astropy.tests.helper import assert_quantity_allclose
 from astropy.uncertainty import distributions as ds
 from astropy.uncertainty.core import Distribution
 from astropy.utils import NumpyRNGContext
+from astropy.utils.compat.numpycompat import NUMPY_LT_1_23
 from astropy.utils.compat.optional_deps import HAS_SCIPY
 
 if HAS_SCIPY:
@@ -321,7 +322,7 @@ def test_reprs():
     ],
 )
 def test_wrong_kw_fails(func, kws):
-    with pytest.raises(Exception):
+    with pytest.raises(TypeError, match="missing 1 required"):
         kw_temp = kws.copy()
         kw_temp["n_sample"] = 100  # note the missing "s"
         assert func(**kw_temp).n_samples == 100
@@ -445,6 +446,47 @@ def test_distr_angle_view_as_quantity():
     assert isinstance(qd3, u.Quantity)
     assert isinstance(qd3, Distribution)
     assert_array_equal(qd3.distribution, qd.distribution)
+    # Simple view with no arguments
+    qd4 = qd3.view()
+    assert qd4.__class__ is qd3.__class__
+    assert np.may_share_memory(qd4, qd3)
+
+
+def test_distr_view_different_dtype1():
+    # Viewing with a new dtype should follow the same rules as for a
+    # regular array with the same dtype.
+    c = Distribution([2.0j, 3.0, 4.0j])
+    r = c.view("2f8")
+    assert r.shape == c.shape + (2,)
+    assert np.may_share_memory(r, c)
+    expected = np.moveaxis(c.distribution.view("2f8"), -2, -1)
+    assert_array_equal(r.distribution, expected)
+    c2 = r.view("c16")
+    assert_array_equal(c2.distribution, c.distribution)
+    assert np.may_share_memory(c2, c)
+
+
+def test_distr_view_different_dtype2():
+    # Viewing with a new dtype should follow the same rules as for a
+    # regular array with the same dtype.
+    uint32 = Distribution(
+        np.array([[0x01020304, 0x05060708], [0x11121314, 0x15161718]], dtype="u4")
+    )
+    uint8 = uint32.view("4u1")
+    assert uint8.shape == uint32.shape + (4,)
+    assert np.may_share_memory(uint8, uint32)
+    expected = np.moveaxis(uint32.distribution.view("4u1"), -2, -1)
+    assert_array_equal(uint8.distribution, expected)
+    uint32_2 = uint8.view("u4")
+    assert np.may_share_memory(uint32_2, uint32)
+    assert_array_equal(uint32_2.distribution, uint32.distribution)
+    uint8_2 = uint8.T
+    if NUMPY_LT_1_23:
+        with pytest.raises(DeprecationWarning, match="Changing the shape of an F-"):
+            uint8_2.view("u4")
+    else:
+        with pytest.raises(ValueError, match="last axis must be contiguous"):
+            uint8_2.view("u4")
 
 
 def test_distr_cannot_view_new_dtype():
@@ -453,16 +495,18 @@ def test_distr_cannot_view_new_dtype():
     # to do with a view as a new dtype, we just error on it.
     # TODO: with a lot of thought, this restriction can likely be relaxed.
     distr = Distribution([2.0, 3.0, 4.0])
-    with pytest.raises(ValueError, match="with a new dtype"):
-        distr.view(np.dtype("f8"))
+    with pytest.raises(ValueError, match="can only be viewed"):
+        distr.view(np.dtype("2i8"))
+
+    with pytest.raises(ValueError, match="can only be viewed"):
+        distr.view(np.dtype("2i8"), distr.__class__)
 
     # Check subclass just in case.
     ad = Angle(distr, "deg")
-    with pytest.raises(ValueError, match="with a new dtype"):
-        ad.view(np.dtype("f8"))
-
-    with pytest.raises(ValueError, match="with a new dtype"):
-        ad.view(np.dtype("f8"), Distribution)
+    with pytest.raises(ValueError, match="can only be viewed"):
+        ad.view(np.dtype("2i8"))
+    with pytest.raises(ValueError, match="can only be viewed"):
+        ad.view("2i8", distr.__class__)
 
 
 def test_scalar_quantity_distribution():
@@ -513,3 +557,143 @@ class TestSetItemWithSelection:
         d = Distribution([90.0, 30.0, 0.0])
         d[d > 50] *= -1.0
         assert_array_equal(d, Distribution([-90.0, 30.0, 0.0]))
+
+
+ADVANCED_INDICES = [
+    (np.array([[1, 2], [0, 1]]), np.array([[1, 3], [0, 2]])),
+    # Same advanced index, but also using negative numbers
+    (np.array([[-2, -1], [0, -2]]), np.array([[1, -1], [-4, -2]])),
+]
+
+
+class TestGetSetItemAdvancedIndex:
+    @classmethod
+    def setup_class(self):
+        self.distribution = np.arange(60.0).reshape(3, 4, 5)
+        self.d = Distribution(self.distribution)
+
+    def test_setup(self):
+        ai1, ai2 = ADVANCED_INDICES[:2]
+        # Check that the first two indices produce the same output.
+        assert_array_equal(self.distribution[ai1], self.distribution[ai2])
+
+    @pytest.mark.parametrize("item", ADVANCED_INDICES)
+    def test_getitem(self, item):
+        v = self.d[item]
+        assert v.shape == item[0].shape
+        assert_array_equal(v.distribution, self.distribution[item])
+
+    @pytest.mark.parametrize("item", [([0, 4],), ([0], [0], [0])])
+    def test_getitem_bad(self, item):
+        with pytest.raises(IndexError):
+            self.d[item]
+
+    @pytest.mark.parametrize("item", ADVANCED_INDICES)
+    def test_setitem(self, item):
+        d = self.d.copy()
+        d[item] = 0.0
+        distribution = self.distribution.copy()
+        distribution[item] = 0.0
+        assert_array_equal(d.distribution, distribution)
+        d[item] = self.d[item]
+        assert_array_equal(d.distribution, self.distribution)
+
+
+class TestQuantityDistributionGetSetItemAdvancedIndex(TestGetSetItemAdvancedIndex):
+    @classmethod
+    def setup_class(self):
+        self.distribution = np.arange(60.0).reshape(3, 4, 5) << u.m
+        self.d = Distribution(self.distribution)
+
+
+class StructuredDtypeBase:
+    @classmethod
+    def setup_class(self):
+        self.dtype = np.dtype([("a", "f8"), ("b", "(2,2)f8")])
+        data = np.arange(5.0) + (np.arange(60.0) * 10).reshape(3, 4, 5, 1)
+        self.distribution = data.view(self.dtype).reshape(3, 4, 5)
+        self.d = Distribution(self.distribution)
+
+
+class TestStructuredQuantityDistributionInit(StructuredDtypeBase):
+    @classmethod
+    def setup_class(self):
+        super().setup_class()
+        self.unit = u.Unit("km, m")
+        self.d_unit = self.unit
+
+    def test_init_via_structured_samples(self):
+        distribution = self.distribution << self.unit
+        d = Distribution(distribution)
+        assert d.unit == self.d_unit
+        assert_array_equal(d.distribution, distribution)
+        assert_array_equal(d.value.distribution, self.distribution)
+
+    def test_init_via_structured_distribution(self):
+        d = self.d << self.unit
+        assert d.unit == self.d_unit
+
+
+class TestStructuredAdvancedIndex(StructuredDtypeBase, TestGetSetItemAdvancedIndex):
+    def test_init(self):
+        assert self.d.shape == (3, 4)
+        assert self.d.n_samples == 5
+        assert_array_equal(self.d.distribution, self.distribution)
+
+
+class TestStructuredDistribution(StructuredDtypeBase):
+    @classmethod
+    def setup_class(self):
+        super().setup_class()
+        self.item = (0.0, [[-1.0, -2.0], [-3.0, -4.0]])
+        self.b_item = [[-1.0, -2.0], [-3.0, -4.0]]
+
+    @pytest.mark.parametrize("item", [-2, slice(1, 3), "a", "b"])
+    def test_getitem(self, item):
+        d_i = self.d[item]
+        assert isinstance(d_i, Distribution)
+        if item in self.dtype.names:
+            assert d_i.shape == self.d.shape + self.dtype[item].shape
+        else:
+            assert d_i.shape == np.ones(self.d.shape)[item].shape
+        assert np.may_share_memory(d_i, self.d)
+        expected = self.distribution[item]
+        if isinstance(item, str):
+            # Sample axis should always be at the end.
+            expected = np.moveaxis(self.distribution[item], self.d.ndim, -1)
+        assert_array_equal(d_i.distribution, expected)
+
+    @pytest.mark.parametrize("item", [1, slice(0, 2)])
+    def test_setitem_index_slice(self, item):
+        d = self.d.copy()
+        distribution = self.distribution.copy()
+        value = self.item
+        d[item] = value
+        distribution[item] = value
+        assert_array_equal(d.distribution, distribution)
+        d[item] = self.d[item]
+        assert_array_equal(d.distribution, self.distribution)
+
+    @pytest.mark.parametrize("item", ["a", "b"])
+    def test_setitem_field(self, item):
+        d = self.d.copy()
+        d[item] = 0.0
+        assert_array_equal(d.distribution[item], np.zeros_like(self.distribution[item]))
+        if item == "b":
+            value = self.b_item  # selected to be a bit tricky.
+            d[item] = value
+            assert_array_equal(
+                d.distribution[item], np.full_like(self.distribution[item], value)
+            )
+        d[item] = self.d[item] * 2.0
+        assert_array_equal(d.distribution[item], self.distribution[item] * 2)
+
+
+class TestStructuredQuantityDistribution(TestStructuredDistribution):
+    @classmethod
+    def setup_class(self):
+        super().setup_class()
+        self.distribution = self.distribution * u.Unit("km,m")
+        self.d = self.d * u.Unit("km,m")
+        self.item = self.item * u.Unit("Mm,km")
+        self.b_item = self.b_item * u.km
