@@ -14,7 +14,7 @@ from .core import UnitBase, def_unit, set_enabled_units
 # To ensure si units of the constants can be interpreted.
 set_enabled_units([si])
 
-import numpy as _numpy
+import numpy as _np  # noqa: E402
 
 _ns = globals()
 
@@ -154,7 +154,7 @@ def_unit(
 )
 def_unit(
     ["R", "Rayleigh", "rayleigh"],
-    (1e10 / (4 * _numpy.pi)) * ph * si.m**-2 * si.s**-1 * si.sr**-1,
+    (1e10 / (4 * _np.pi)) * ph * si.m**-2 * si.s**-1 * si.sr**-1,
     namespace=_ns,
     prefixes=True,
     doc="Rayleigh: photon flux",
@@ -226,31 +226,9 @@ del si
 ###########################################################################
 # DOCSTRING
 
-# This generates a docstring for this module that describes all of the
-# standard units defined here.
-from .utils import generate_unit_summary as _generate_unit_summary
-
 if __doc__ is not None:
+    # This generates a docstring for this module that describes all of the
+    # standard units defined here.
+    from .utils import generate_unit_summary as _generate_unit_summary
+
     __doc__ += _generate_unit_summary(globals())
-
-
-# -------------------------------------------------------------------------
-
-
-def __getattr__(attr):
-    if attr == "littleh":
-        import warnings
-
-        from astropy.cosmology.units import littleh
-        from astropy.utils.exceptions import AstropyDeprecationWarning
-
-        warnings.warn(
-            "`littleh` is deprecated from module `astropy.units.astrophys` "
-            "since astropy 5.0 and may be removed in a future version. "
-            "Use `astropy.cosmology.units.littleh` instead.",
-            AstropyDeprecationWarning,
-        )
-
-        return littleh
-
-    raise AttributeError(f"module {__name__!r} has no attribute {attr!r}.")
