@@ -3,9 +3,7 @@
 """
 Handles the "Unicode" unit format.
 """
-
-
-from . import console
+from . import console, utils
 
 
 class Unicode(console.Console):
@@ -33,6 +31,16 @@ class Unicode(console.Console):
     def _format_mantissa(cls, m):
         return m.replace("-", "−")
 
+    @classmethod
+    def _format_unit_power(cls, unit, power=1):
+        name = cls._get_unit_name(unit)
+        # Check for superscript units
+        if power != 1:
+            if name in ("°", "e⁻", "″", "′", "ʰ"):
+                name = unit.short_names[0]
+            name += cls._format_superscript(utils.format_power(power))
+        return name
+
     @classmethod
     def _format_superscript(cls, number):
         mapping = str.maketrans(
