@@ -12,7 +12,16 @@ from astropy import constants
 from astropy import units as u
 from astropy.tests.helper import assert_quantity_allclose
 from astropy.units.equivalencies import Equivalency
-from astropy.utils.exceptions import AstropyDeprecationWarning
+
+
+def test_find_equivalent_units():
+    # Only finds units in the namespace
+    e1 = (u.m**3).find_equivalent_units()
+    assert len(e1) == 1
+    assert e1[0] == u.l
+    # Regression test for gh-16124
+    e2 = (u.m**-3).find_equivalent_units()
+    assert len(e2) == 0
 
 
 def test_dimensionless_angles():
@@ -700,22 +709,6 @@ def test_brightness_temperature():
     )
 
 
-def test_swapped_args_brightness_temperature():
-    """
-    #5173 changes the order of arguments but accepts the old (deprecated) args
-    """
-    omega_B = np.pi * (50 * u.arcsec) ** 2
-    nu = u.GHz * 5
-    tb = 7.052587837212582 * u.K
-
-    with pytest.warns(AstropyDeprecationWarning) as w:
-        result = (1 * u.Jy).to(u.K, equivalencies=u.brightness_temperature(omega_B, nu))
-        roundtrip = result.to(u.Jy, equivalencies=u.brightness_temperature(omega_B, nu))
-    assert len(w) == 2
-    np.testing.assert_almost_equal(tb.value, result.value)
-    np.testing.assert_almost_equal(roundtrip.value, 1)
-
-
 def test_surfacebrightness():
     sb = 50 * u.MJy / u.sr
     k = sb.to(u.K, u.brightness_temperature(50 * u.GHz))
@@ -900,7 +893,7 @@ def test_compose_equivalencies():
             )
             break
     else:
-        assert False, "Didn't find speed in compose results"
+        raise AssertionError("Didn't find speed in compose results")
 
 
 def test_pixel_scale():
@@ -972,7 +965,7 @@ def test_equivelency():
     assert ps.name[0] == "pixel_scale"
     assert isinstance(ps.kwargs, list)
     assert len(ps.kwargs) == 1
-    assert ps.kwargs[0] == dict({"pixscale": 10 * u.arcsec / u.pix})
+    assert ps.kwargs[0] == {"pixscale": 10 * u.arcsec / u.pix}
 
 
 def test_add_equivelencies():
@@ -980,7 +973,7 @@ def test_add_equivelencies():
     assert isinstance(e1, Equivalency)
     assert e1.name == ["pixel_scale", "temperature_energy"]
     assert isinstance(e1.kwargs, list)
-    assert e1.kwargs == [dict({"pixscale": 10 * u.arcsec / u.pix}), dict()]
+    assert e1.kwargs == [{"pixscale": 10 * u.arcsec / u.pix}, dict()]
 
     e2 = u.pixel_scale(10 * u.arcsec / u.pixel) + [1, 2, 3]
     assert isinstance(e2, list)
