@@ -14,6 +14,7 @@ from numpy.testing import assert_allclose, assert_array_almost_equal, assert_arr
 from astropy import units as u
 from astropy.units.quantity import _UNIT_NOT_INITIALISED
 from astropy.utils import isiterable, minversion
+from astropy.utils.compat import COPY_IF_NEEDED
 from astropy.utils.exceptions import AstropyWarning
 
 """ The Quantity class will represent a number + unit + uncertainty """
@@ -493,7 +494,7 @@ class TestQuantityOperations:
         assert new_quantity.value == -self.q1.value
         assert new_quantity.unit == self.q1.unit
 
-        new_quantity = -(-self.q1)
+        new_quantity = -(-self.q1)  # noqa: B002
         assert new_quantity.value == self.q1.value
         assert new_quantity.unit == self.q1.unit
 
@@ -1640,8 +1641,8 @@ class QuantityMimic:
         self.value = value
         self.unit = unit
 
-    def __array__(self):
-        return np.array(self.value)
+    def __array__(self, dtype=None, copy=COPY_IF_NEEDED):
+        return np.array(self.value, dtype=dtype, copy=copy)
 
 
 class QuantityMimic2(QuantityMimic):
