@@ -5,7 +5,7 @@ import itertools
 import numpy as np
 import numpy.lib.recfunctions as rfn
 import pytest
-from numpy.testing import assert_array_equal
+from numpy.testing import assert_allclose, assert_array_equal
 
 from astropy import units as u
 from astropy.units.quantity_helper.function_helpers import (
@@ -17,7 +17,12 @@ from astropy.units.quantity_helper.function_helpers import (
     TBD_FUNCTIONS,
     UNSUPPORTED_FUNCTIONS,
 )
-from astropy.utils.compat import NUMPY_LT_1_23, NUMPY_LT_1_24
+from astropy.utils.compat import (
+    NUMPY_LT_1_23,
+    NUMPY_LT_1_24,
+    NUMPY_LT_1_25,
+    NUMPY_LT_2_0,
+)
 
 needs_array_function = pytest.mark.xfail(
     not ARRAY_FUNCTION_ENABLED, reason="Needs __array_function__ support"
@@ -25,15 +30,32 @@ needs_array_function = pytest.mark.xfail(
 
 
 # To get the functions that could be covered, we look for those that
-# are wrapped.  Of course, this does not give a full list pre-1.17.
+# are in modules we care about and have been overridden.
 def get_wrapped_functions(*modules):
+    if NUMPY_LT_1_25:
+
+        def allows_array_function_override(f):
+            return (
+                hasattr(f, "__wrapped__")
+                and f is not np.printoptions
+                and not f.__name__.startswith("_")
+            )
+
+    else:
+        from numpy.testing.overrides import allows_array_function_override
+
     wrapped_functions = {}
     for mod in modules:
         for name, f in mod.__dict__.items():
-            if f is np.printoptions or name.startswith("_"):
-                continue
-            if callable(f) and hasattr(f, "__wrapped__"):
+            if callable(f) and allows_array_function_override(f):
+                # Indexing by just the name is easiest for test writing,
+                # but in numpy 2.0, there are 2 versions of diagonal and
+                # trace, one in the main namespace, and one in np.linalg.
+                # So, we distinguish those by adding the module name.
+                if name in wrapped_functions:
+                    name = mod.__name__.replace("numpy.", "") + "_" + name
                 wrapped_functions[name] = f
+
     return wrapped_functions
 
 
@@ -187,6 +209,11 @@ class TestShapeManipulation(InvariantUnitTestSetup):
         assert type(a1) is np.ndarray
         assert type(a2) is np.ndarray
 
+    if not NUMPY_LT_2_0:
+
+        def test_matrix_transpose(self):
+            self.check(np.matrix_transpose)
+
 
 class TestArgFunctions(NoUnitTestSetup):
     def test_argmin(self):
@@ -286,6 +313,7 @@ class TestCopyAndCreation(InvariantUnitTestSetup):
         copy = np.copy(a=self.q)
         assert_array_equal(copy, self.q)
 
+    @pytest.mark.skipif(not NUMPY_LT_2_0, reason="np.asfarray is removed in NumPy 2.0")
     @needs_array_function
     def test_asfarray(self):
         self.check(np.asfarray)
@@ -321,6 +349,12 @@ class TestCopyAndCreation(InvariantUnitTestSetup):
         with pytest.raises(u.UnitsError):
             np.full_like(self.q, 0.5 * u.s)
 
+    if not NUMPY_LT_2_0:
+
+        def test_astype(self):
+            int32q = self.q.astype("int32")
+            assert_array_equal(np.astype(int32q, "int32"), int32q)
+
 
 class TestAccessingParts(InvariantUnitTestSetup):
     def test_diag(self):
@@ -608,6 +642,12 @@ class TestSplit(metaclass=CoverageMeta):
 
 
 class TestUfuncReductions(InvariantUnitTestSetup):
+    def test_max(self):
+        self.check(np.max)
+
+    def test_min(self):
+        self.check(np.min)
+
     def test_amax(self):
         self.check(np.amax)
 
@@ -628,29 +668,39 @@ class TestUfuncReductions(InvariantUnitTestSetup):
         with pytest.raises(TypeError):
             np.all(self.q)
 
+    @pytest.mark.skipif(not NUMPY_LT_2_0, reason="np.sometrue is removed in NumPy 2.0")
+    @pytest.mark.filterwarnings("ignore:`sometrue` is deprecated as of NumPy 1.25.0")
     def test_sometrue(self):
         with pytest.raises(TypeError):
-            np.sometrue(self.q)
+            np.sometrue(self.q)  # noqa: NPY003
 
+    @pytest.mark.skipif(not NUMPY_LT_2_0, reason="np.alltrue is removed in NumPy 2.0")
+    @pytest.mark.filterwarnings("ignore:`alltrue` is deprecated as of NumPy 1.25.0")
     def test_alltrue(self):
         with pytest.raises(TypeError):
-            np.alltrue(self.q)
+            np.alltrue(self.q)  # noqa: NPY003
 
     def test_prod(self):
         with pytest.raises(u.UnitsError):
             np.prod(self.q)
 
+    @pytest.mark.skipif(not NUMPY_LT_2_0, reason="np.product is removed in NumPy 2.0")
+    @pytest.mark.filterwarnings("ignore:`product` is deprecated as of NumPy 1.25.0")
     def test_product(self):
         with pytest.raises(u.UnitsError):
-            np.product(self.q)
+            np.product(self.q)  # noqa: NPY003
 
     def test_cumprod(self):
         with pytest.raises(u.UnitsError):
             np.cumprod(self.q)
 
+    @pytest.mark.skipif(
+        not NUMPY_LT_2_0, reason="np.cumproduct is removed in NumPy 2.0"
+    )
+    @pytest.mark.filterwarnings("ignore:`cumproduct` is deprecated as of NumPy 1.25.0")
     def test_cumproduct(self):
         with pytest.raises(u.UnitsError):
-            np.cumproduct(self.q)
+            np.cumproduct(self.q)  # noqa: NPY003
 
 
 class TestUfuncLike(InvariantUnitTestSetup):
@@ -658,8 +708,13 @@ class TestUfuncLike(InvariantUnitTestSetup):
         self.check(np.ptp)
         self.check(np.ptp, axis=0)
 
+    def test_round(self):
+        self.check(np.round)
+
+    @pytest.mark.skipif(not NUMPY_LT_2_0, reason="np.round_ is removed in NumPy 2.0")
+    @pytest.mark.filterwarnings("ignore:`round_` is deprecated as of NumPy 1.25.0")
     def test_round_(self):
-        self.check(np.round_)
+        self.check(np.round_)  # noqa: NPY003
 
     def test_around(self):
         self.check(np.around)
@@ -853,6 +908,12 @@ class TestReductionLikeFunctions(InvariantUnitTestSetup):
     def test_median(self):
         self.check(np.median)
 
+    def test_median_nan_scalar(self):
+        # See gh-12165; this dropped the unit in numpy < 1.22
+        data = [1.0, 2, np.nan, 3, 4] << u.km
+        result = np.median(data)
+        assert_array_equal(result, np.nan * u.km)
+
     @needs_array_function
     def test_quantile(self):
         self.check(np.quantile, 0.5)
@@ -924,6 +985,17 @@ class TestReductionLikeFunctions(InvariantUnitTestSetup):
         q3 = q1.value * u.cm
         assert not np.array_equal(q1, q3)
 
+    @pytest.mark.parametrize("equal_nan", [False, True])
+    def test_array_equal_nan(self, equal_nan):
+        q1 = np.linspace(0, 1, num=11) * u.m
+        q1[0] = np.nan
+        q2 = q1.to(u.cm)
+        result = np.array_equal(q1, q2, equal_nan=equal_nan)
+        assert result == equal_nan
+
+    def test_array_equal_incompatible_units(self):
+        assert not np.array_equal([1, 2] * u.m, [1, 2] * u.s)
+
     @needs_array_function
     def test_array_equiv(self):
         q1 = np.array([[0.0, 1.0, 2.0]] * 3) * u.m
@@ -932,6 +1004,9 @@ class TestReductionLikeFunctions(InvariantUnitTestSetup):
         q3 = q1[0].value * u.cm
         assert not np.array_equiv(q1, q3)
 
+    def test_array_equiv_incompatible_units(self):
+        assert not np.array_equiv([1, 1] * u.m, [1] * u.s)
+
 
 class TestNanFunctions(InvariantUnitTestSetup):
     def setup_method(self):
@@ -957,8 +1032,15 @@ class TestNanFunctions(InvariantUnitTestSetup):
     def test_nanmean(self):
         self.check(np.nanmean)
 
-    def test_nanmedian(self):
-        self.check(np.nanmedian)
+    @pytest.mark.parametrize("axis", [None, 0, 1, -1])
+    def test_nanmedian(self, axis):
+        self.check(np.nanmedian, axis=axis)
+
+    def test_nanmedian_out(self):
+        out = np.empty_like(self.q)
+        o = np.nanmedian(self.q, out=out)
+        assert o is out
+        assert np.all(o == np.nanmedian(self.q))
 
     def test_nansum(self):
         self.check(np.nansum)
@@ -1091,22 +1173,32 @@ class TestVariousProductFunctions(metaclass=CoverageMeta):
 
 
 class TestIntDiffFunctions(metaclass=CoverageMeta):
-    def test_trapz(self):
+    def check_trapezoid(self, func):
         y = np.arange(9.0) * u.m / u.s
-        out = np.trapz(y)
-        expected = np.trapz(y.value) * y.unit
+        out = func(y)
+        expected = func(y.value) * y.unit
         assert np.all(out == expected)
 
         dx = 10.0 * u.s
-        out = np.trapz(y, dx=dx)
-        expected = np.trapz(y.value, dx=dx.value) * y.unit * dx.unit
+        out = func(y, dx=dx)
+        expected = func(y.value, dx=dx.value) * y.unit * dx.unit
         assert np.all(out == expected)
 
         x = np.arange(9.0) * u.s
-        out = np.trapz(y, x)
-        expected = np.trapz(y.value, x.value) * y.unit * x.unit
+        out = func(y, x)
+        expected = func(y.value, x.value) * y.unit * x.unit
         assert np.all(out == expected)
 
+    if NUMPY_LT_2_0:
+
+        def test_trapz(self):
+            self.check_trapezoid(np.trapz)
+
+    else:
+
+        def test_trapezoid(self):
+            self.check_trapezoid(np.trapezoid)
+
     def test_diff(self):
         # Simple diff works out of the box.
         x = np.arange(10.0) * u.m
@@ -1279,7 +1371,7 @@ class TestHistogramFunctions(metaclass=CoverageMeta):
         value_args=None,
         value_kwargs=None,
         expected_units=None,
-        **kwargs
+        **kwargs,
     ):
         """Check quanties are treated correctly in the histogram function.
         Test is done by applying ``function(*args, **kwargs)``, where
@@ -1814,7 +1906,7 @@ class TestMemoryFunctions(NoUnitTestSetup):
         self.check(np.may_share_memory, self.q.value)
 
 
-class TestSetOpsFcuntions(metaclass=CoverageMeta):
+class TestSetOpsFunctions(metaclass=CoverageMeta):
     def setup_method(self):
         self.q = np.array([[0.0, 1.0, -1.0], [3.0, 5.0, 3.0], [0.0, 1.0, -1]]) * u.m
         self.q2 = np.array([0.0, 100.0, 150.0, 200.0]) * u.cm
@@ -1863,6 +1955,51 @@ class TestSetOpsFcuntions(metaclass=CoverageMeta):
     def test_unique_more_complex(self, kwargs):
         self.check1(np.unique, **kwargs)
 
+    if not NUMPY_LT_2_0:
+
+        @needs_array_function
+        def test_unique_all(self):
+            values, indices, inverse_indices, counts = np.unique(
+                self.q,
+                return_index=True,
+                return_inverse=True,
+                return_counts=True,
+                equal_nan=False,
+            )
+            res = np.unique_all(self.q)
+            assert len(res) == 4
+
+            assert_array_equal(res.values, values)
+            assert_array_equal(res.indices, indices)
+            assert_array_equal(res.inverse_indices, inverse_indices)
+            assert_array_equal(res.counts, counts)
+
+        @needs_array_function
+        def test_unique_counts(self):
+            values, counts = np.unique(self.q, return_counts=True, equal_nan=False)
+            res = np.unique_counts(self.q)
+            assert len(res) == 2
+
+            assert_array_equal(res.values, values)
+            assert_array_equal(res.counts, counts)
+
+        @needs_array_function
+        def test_unique_inverse(self):
+            values, inverse_indices = np.unique(
+                self.q, return_inverse=True, equal_nan=False
+            )
+            res = np.unique_inverse(self.q)
+            assert len(res) == 2
+
+            assert_array_equal(res.values, values)
+            assert_array_equal(res.inverse_indices, inverse_indices)
+
+        @needs_array_function
+        def test_unique_values(self):
+            values = np.unique(self.q, equal_nan=False)
+            res = np.unique_values(self.q)
+            assert_array_equal(res, values)
+
     @needs_array_function
     @pytest.mark.parametrize("kwargs", (dict(), dict(return_indices=True)))
     def test_intersect1d(self, kwargs):
@@ -1884,6 +2021,7 @@ class TestSetOpsFcuntions(metaclass=CoverageMeta):
         self.check2(np.setdiff1d)
 
     @needs_array_function
+    @pytest.mark.filterwarnings("ignore:`in1d` is deprecated. Use `np.isin` instead.")
     def test_in1d(self):
         self.check2(np.in1d, unit=None)
         # Check zero is treated as having any unit.
@@ -1987,15 +2125,11 @@ class TestFFT(InvariantUnitTestSetup):
         self.check(np.fft.ifftshift)
 
 
-class TestLinAlg(metaclass=CoverageMeta):
+class TestLinAlg(InvariantUnitTestSetup, metaclass=CoverageMeta):
     def setup_method(self):
         self.q = (
-            np.array(
-                [[ 1.0, -1.0,  2.0],  # noqa: E201
-                 [ 0.0,  3.0, -1.0],  # noqa: E201
-                 [-1.0, -1.0,  1.0]]
-            ) << u.m
-        )  # fmt: skip
+            np.array([[1.0, -1.0, 2.0], [0.0, 3.0, -1.0], [-1.0, -1.0, 1.0]]) << u.m
+        )
 
     def test_cond(self):
         c = np.linalg.cond(self.q)
@@ -2073,6 +2207,9 @@ class TestLinAlg(metaclass=CoverageMeta):
             np.linalg.pinv(self.q.value, rcond.to_value(self.q.unit)) / self.q.unit
         )
         assert_array_equal(pinv2, expected2)
+        if not NUMPY_LT_2_0:
+            pinv3 = np.linalg.pinv(self.q, rtol=rcond)
+            assert_array_equal(pinv3, expected2)
 
     @needs_array_function
     def test_tensorinv(self):
@@ -2214,6 +2351,84 @@ class TestLinAlg(metaclass=CoverageMeta):
         wx = np.linalg.eigvalsh(self.q.value) << self.q.unit
         assert_array_equal(w, wx)
 
+    if not NUMPY_LT_2_0:
+        # Numpy 2.0 added array-api compatible definitions of
+        # diagonal and trace to np.linalg. Since these have
+        # name conflicts with the main numpy namespace, they
+        # are tracked as linalg_diagonal and linalg_trace.
+        def test_linalg_diagonal(self):
+            self.check(np.linalg.diagonal)
+
+        def test_linalg_trace(self):
+            self.check(np.trace)
+
+        @needs_array_function
+        def test_linalg_cross(self):
+            q1 = np.array([1, 2, 3]) << u.m
+            q2 = np.array([4, 5, 6]) << u.s
+            assert_array_equal(np.linalg.cross(q1, q2), np.cross(q1, q2))
+            assert_array_equal(np.linalg.cross(q1, q2.value), np.cross(q1, q2.value))
+
+        @needs_array_function
+        def test_linalg_outer(self):
+            q = self.q.flatten()
+            assert_array_equal(np.linalg.outer(q, q), np.outer(q, q))
+            assert_array_equal(np.linalg.outer(q, q.value), np.outer(q, q.value))
+
+        @needs_array_function
+        def test_svdvals(self):
+            # TODO: this function should be named test_linalg_svdvals
+            # but at the moment this breaks the completion test
+            # see https://github.com/astropy/astropy/issues/15692
+            _, ref, _ = np.linalg.svd(self.q)
+            res = np.linalg.svdvals(self.q)
+            assert_allclose(res, ref, rtol=5e-16)
+
+        @needs_array_function
+        def test_vecdot(self):
+            ref = (self.q * self.q).sum(-1)
+            res = np.linalg.vecdot(self.q, self.q)
+            assert_array_equal(res, ref)
+
+        @needs_array_function
+        def test_linalg_tensordot(self):
+            ref = np.tensordot(self.q, self.q)
+            res = np.linalg.tensordot(self.q, self.q)
+            assert_array_equal(res, ref)
+
+        @needs_array_function
+        def test_matmul(self):
+            # see https://github.com/astropy/astropy/issues/15692
+            ref = np.matmul(self.q, self.q)
+            res = np.linalg.matmul(self.q, self.q)
+            assert_array_equal(res, ref)
+
+        def test_linalg_matrix_transpose(self):
+            t = np.linalg.matrix_transpose(self.q)
+            assert_array_equal(t, self.q.swapaxes(-2, -1))
+
+        @needs_array_function
+        def test_matrix_norm(self):
+            n = np.linalg.matrix_norm(self.q)
+            expected = np.linalg.norm(self.q.value) << self.q.unit
+            assert_array_equal(n, expected)
+
+        @needs_array_function
+        def test_vector_norm(self):
+            n = np.linalg.vector_norm(self.q)
+            expected = np.linalg.norm(self.q.value.ravel()) << self.q.unit
+            assert_array_equal(n, expected)
+            # Special case: 1-D, ord=0.
+            n1 = np.linalg.vector_norm(self.q[0], ord=0)
+            expected1 = np.linalg.norm(self.q[0].value.ravel(), ord=0) << u.one
+            assert_array_equal(n1, expected1)
+            # Axis combo, just in case
+            n2 = np.linalg.vector_norm(self.q, axis=(-1, -2))
+            expected2 = (
+                np.linalg.vector_norm(self.q.value, axis=(-1, -2)) << self.q.unit
+            )
+            assert_array_equal(n2, expected2)
+
 
 class TestRecFunctions(metaclass=CoverageMeta):
     @classmethod
@@ -2304,18 +2519,17 @@ class TestRecFunctions(metaclass=CoverageMeta):
         assert np.array_equal(arr, self.q_pv)
         assert arr.unit == (u.km, u.km / u.s)
 
-    @pytest.mark.xfail
-    @pytest.mark.parametrize("flatten", [True, False])
-    def test_merge_arrays_nonquantities(self, flatten):
-        # Fails because cannot create quantity from structured array.
-        arr = rfn.merge_arrays((q_pv["p"], q_pv.value), flatten=flatten)
-
     def test_merge_array_nested_structure(self):
         # Merge 2-element tuples without flattening.
         arr = rfn.merge_arrays((self.q_pv, self.q_pv_t))
         assert_array_equal(arr["f0"], self.q_pv)
         assert_array_equal(arr["f1"], self.q_pv_t)
         assert arr.unit == ((u.km, u.km / u.s), ((u.km, u.km / u.s), u.s))
+        # For a structured array, all elements should be treated as dimensionless.
+        arr = rfn.merge_arrays((self.q_pv["p"], self.q_pv.value))
+        expected_value = rfn.merge_arrays((self.q_pv["p"].value, self.q_pv.value))
+        assert_array_equal(arr.value, expected_value)
+        assert arr.unit == u.Unit((self.q_pv["p"].unit, (u.one, u.one)))
 
     def test_merge_arrays_flatten_nested_structure(self):
         # Merge 2-element tuple, flattening it.
@@ -2326,6 +2540,13 @@ class TestRecFunctions(metaclass=CoverageMeta):
         assert_array_equal(arr["vv"], self.q_pv_t["pv"]["vv"])
         assert_array_equal(arr["t"], self.q_pv_t["t"])
         assert arr.unit == (u.km, u.km / u.s, u.km, u.km / u.s, u.s)
+        # For a structured array, all elements should be treated as dimensionless.
+        arr = rfn.merge_arrays((self.q_pv["p"], self.q_pv.value), flatten=True)
+        expected_value = rfn.merge_arrays(
+            (self.q_pv["p"].value, self.q_pv.value), flatten=True
+        )
+        assert_array_equal(arr.value, expected_value)
+        assert arr.unit == u.Unit((self.q_pv["p"].unit, u.one, u.one))
 
     def test_merge_arrays_asrecarray(self):
         with pytest.raises(ValueError, match="asrecarray=True is not supported."):
