@@ -5,6 +5,7 @@ The tests here are fairly detailed but do not aim for complete
 coverage.  Complete coverage of all numpy functions is done
 with less detailed tests in test_function_helpers.
 """
+import erfa.ufunc as erfa_ufunc
 import numpy as np
 import pytest
 from numpy.testing import assert_array_equal
@@ -151,6 +152,57 @@ class MaskedUfuncTests(MaskedArraySetup):
         assert_array_equal(ma_mb.unmasked, expected_data)
         assert_array_equal(ma_mb.mask, expected_mask)
 
+    def test_multi_op_ufunc(self):
+        mask = [True, False, False]
+        iy = Masked([2000, 2001, 2002], mask=mask)
+        im = Masked([1, 2, 3], mask=mask)
+        idy = Masked([10, 20, 25], mask=mask)
+        ihr = Masked([11, 12, 13], mask=[False, False, True])
+        imn = np.array([50, 51, 52])
+        isc = np.array([12.5, 13.6, 14.7])
+        result = erfa_ufunc.dtf2d("utc", iy, im, idy, ihr, imn, isc)
+        # Also test scalar
+        result0 = erfa_ufunc.dtf2d("utc", iy[0], im[0], idy[0], ihr[0], imn[0], isc[0])
+        expected = erfa_ufunc.dtf2d(
+            "utc", iy.unmasked, im.unmasked, idy.unmasked, ihr.unmasked, imn, isc
+        )
+        expected_mask = np.array([True, False, True])
+        for res, res0, exp in zip(result, result0, expected):
+            assert_array_equal(res.unmasked, exp)
+            assert_array_equal(res.mask, expected_mask)
+            assert res0.unmasked == exp[0]
+            assert res0.mask == expected_mask[0]
+
+    def test_erfa_rxp(self):
+        # Regression tests for gh-16116
+        m = Masked(np.eye(3))
+        v = Masked(np.arange(6).reshape(2, 3))
+        rxp1 = erfa_ufunc.rxp(m, v)
+        exp = erfa_ufunc.rxp(m.unmasked, v.unmasked)
+        assert_array_equal(rxp1.unmasked, exp)
+        assert_array_equal(rxp1.mask, False)
+        v.mask[0, 0] = True
+        rxp2 = erfa_ufunc.rxp(m, v)
+        assert_array_equal(rxp2.unmasked, exp)
+        assert_array_equal(rxp2.mask, [[True] * 3, [False] * 3])
+        m.mask[1, 1] = True
+        v.mask[...] = False
+        rxp3 = erfa_ufunc.rxp(m, v)
+        assert_array_equal(rxp3.unmasked, exp)
+        assert_array_equal(rxp3.mask, True)
+
+    def test_erfa_rxr(self):
+        m1 = Masked(np.arange(27.0).reshape(3, 3, 3))
+        m2 = Masked(np.arange(-27.0, 0.0).reshape(3, 3, 3))
+        rxr1 = erfa_ufunc.rxr(m1, m2)
+        exp = erfa_ufunc.rxr(m1.unmasked, m2.unmasked)
+        assert_array_equal(rxr1.unmasked, exp)
+        assert_array_equal(rxr1.mask, False)
+        m1.mask[0, 1, 2] = True
+        rxr2 = erfa_ufunc.rxr(m1, m2)
+        assert_array_equal(rxr2.unmasked, exp)
+        assert np.all(rxr2.mask == [[[True]], [[False]], [[False]]])
+
     @pytest.mark.parametrize("axis", (0, 1, None))
     def test_add_reduce(self, axis):
         ma_reduce = np.add.reduce(self.ma, axis=axis)
