@@ -4,6 +4,7 @@
 Functions, including ufuncs, are tested in test_functions.py
 """
 import operator
+import sys
 
 import numpy as np
 import pytest
@@ -12,7 +13,6 @@ from numpy.testing import assert_array_equal
 from astropy import units as u
 from astropy.coordinates import Longitude
 from astropy.units import Quantity
-from astropy.utils.compat import NUMPY_LT_1_22
 from astropy.utils.masked import Masked, MaskedNDArray
 
 
@@ -296,40 +296,42 @@ class TestMaskedQuantityInitialization(TestMaskedArrayInitialization, QuantitySe
         super().setup_class()
         # Ensure we have used MaskedQuantity before - just in case a single test gets
         # called; see gh-15316.
-        Masked(Quantity)
+        self.MQ = Masked(Quantity)
+
+    def test_masked_quantity_getting(self):
+        # First check setup_class (or previous use) defined a cache entry.
+        mcls = Masked._masked_classes[type(self.a)]
+        # Next check this is what one gets now.
+        MQ = Masked(Quantity)
+        assert MQ is mcls
+        assert issubclass(MQ, Quantity)
+        assert issubclass(MQ, Masked)
+        # And also what one gets implicitly.
+        mq = Masked([1.0, 2.0] * u.m)
+        assert isinstance(mq, MQ)
 
     def test_masked_quantity_class_init(self):
-        # TODO: class definitions should be more easily accessible.
-        mcls = Masked._masked_classes[self.a.__class__]
         # This is not a very careful test.
-        mq = mcls([1.0, 2.0], mask=[True, False], unit=u.s)
+        mq = self.MQ([1.0, 2.0], mask=[True, False], unit=u.s)
         assert mq.unit == u.s
         assert np.all(mq.value.unmasked == [1.0, 2.0])
         assert np.all(mq.value.mask == [True, False])
         assert np.all(mq.mask == [True, False])
 
-    def test_masked_quantity_getting(self):
-        mcls = Masked._masked_classes[self.a.__class__]
-        MQ = Masked(Quantity)
-        assert MQ is mcls
-
     def test_initialization_without_mask(self):
         # Default for not giving a mask should be False.
-        MQ = Masked(Quantity)
-        mq = MQ([1.0, 2.0], u.s)
+        mq = self.MQ([1.0, 2.0], u.s)
         assert mq.unit == u.s
         assert np.all(mq.value.unmasked == [1.0, 2.0])
         assert np.all(mq.mask == [False, False])
 
     @pytest.mark.parametrize("masked_array", [Masked, np.ma.MaskedArray])
     def test_initialization_with_masked_values(self, masked_array):
-        MQ = Masked(Quantity)
         a = np.array([1.0, 2.0])
         m = np.array([True, False])
         ma = masked_array(a, m)
-        mq = MQ(ma)
-        assert isinstance(mq, Masked)
-        assert isinstance(mq, Quantity)
+        mq = self.MQ(ma)
+        assert isinstance(mq, self.MQ)
         assert_array_equal(mq.value.unmasked, a)
         assert_array_equal(mq.mask, m)
 
@@ -695,7 +697,7 @@ class MaskedOperatorTests(MaskedArraySetup):
 
     def test_not_implemented(self):
         with pytest.raises(TypeError):
-            self.ma > "abc"
+            self.ma > "abc"  # noqa: B015
 
     @pytest.mark.parametrize("different_names", [False, True])
     @pytest.mark.parametrize("op", (operator.eq, operator.ne))
@@ -792,7 +794,7 @@ class TestMaskedArrayOperators(MaskedOperatorTests):
 
     def test_not_implemented(self):
         with pytest.raises(TypeError):
-            Masked(["a", "b"]) > object()
+            Masked(["a", "b"]) > object()  # noqa: B015
 
 
 class TestMaskedQuantityOperators(MaskedOperatorTests, QuantitySetup):
@@ -1055,11 +1057,9 @@ class TestMaskedArrayMethods(MaskedArraySetup):
         ma = Masked(data=[1, 2], mask=[True, False])
         assert ma.argmin() == 1
 
-    if not NUMPY_LT_1_22:
-
-        def test_argmin_keepdims(self):
-            ma = Masked(data=[[1, 2], [3, 4]], mask=[[True, False], [False, False]])
-            assert_array_equal(ma.argmin(axis=0, keepdims=True), np.array([[1, 0]]))
+    def test_argmin_keepdims(self):
+        ma = Masked(data=[[1, 2], [3, 4]], mask=[[True, False], [False, False]])
+        assert_array_equal(ma.argmin(axis=0, keepdims=True), np.array([[1, 0]]))
 
     @pytest.mark.parametrize("axis", (0, 1, None))
     def test_argmax(self, axis):
@@ -1069,11 +1069,9 @@ class TestMaskedArrayMethods(MaskedArraySetup):
         expected_data = filled.argmax(axis)
         assert_array_equal(ma_argmax, expected_data)
 
-    if not NUMPY_LT_1_22:
-
-        def test_argmax_keepdims(self):
-            ma = Masked(data=[[1, 2], [3, 4]], mask=[[True, False], [False, False]])
-            assert_array_equal(ma.argmax(axis=1, keepdims=True), np.array([[1], [1]]))
+    def test_argmax_keepdims(self):
+        ma = Masked(data=[[1, 2], [3, 4]], mask=[[True, False], [False, False]])
+        assert_array_equal(ma.argmax(axis=1, keepdims=True), np.array([[1], [1]]))
 
     @pytest.mark.parametrize("axis", (0, 1, None))
     def test_argsort(self, axis):
@@ -1297,17 +1295,46 @@ class TestMaskedArrayProductMethods(MaskedArraySetup):
         assert_array_equal(ma_sum.mask, expected_mask)
 
 
-def test_masked_str_explicit():
+def test_masked_str_repr_explicit_float():
+    sa = np.array([np.pi, 2 * np.pi])
+    msa = Masked(sa, [False, True])
+    # Test masking  the array works as expected, including truncating digits
+    assert str(msa) == "[3.14159265        ———]"
+    # Test the digits are kept for scalars.
+    assert str(msa[0]) == "3.141592653589793" == str(sa[0])
+    # And that the masked string has the same length.
+    assert str(msa[1]) == "              ———"
+    # Test temporary precision change (which does not affect scalars).
+    with np.printoptions(precision=3, floatmode="fixed"):
+        assert str(msa) == "[3.142   ———]"
+        assert str(msa[0]) == "3.141592653589793" == str(sa[0])
+    assert repr(msa) == "MaskedNDArray([3.14159265,        ———])"
+
+
+def test_masked_str_explicit_string():
+    sa = np.array(["2001-02-03", "2002-03-04"])
+    msa = Masked(sa, [False, True])
+    assert str(msa) == "['2001-02-03'          ———]"
+    assert str(msa[0]) == "2001-02-03" == str(sa[0])
+    assert str(msa[1]) == "       ———"
+    byteorder = "<" if sys.byteorder == "little" else ">"
+    repr_ = f"MaskedNDArray(['2001-02-03',          ———], dtype='{byteorder}U10')"
+    assert repr(msa) == repr_
+
+
+def test_masked_str_explicit_structured():
     sa = np.array([(1.0, 2.0), (3.0, 4.0)], dtype="f8,f8")
     msa = Masked(sa, [(False, True), (False, False)])
     assert str(msa) == "[(1., ——) (3., 4.)]"
     assert str(msa[0]) == "(1., ——)"
-    assert str(msa[1]) == "(3., 4.)"
+    assert str(msa[1]) == "(3., 4.)" == str(sa[1])
     with np.printoptions(precision=3, floatmode="fixed"):
         assert str(msa) == "[(1.000,   ———) (3.000, 4.000)]"
+        assert str(msa[0]) == "(1.000,   ———)"
+        assert str(msa[1]) == "(3.000, 4.000)" == str(sa[1])
 
 
-def test_masked_repr_explicit():
+def test_masked_repr_explicit_structured():
     # Use explicit endianness to ensure tests pass on all architectures
     sa = np.array([(1.0, 2.0), (3.0, 4.0)], dtype=">f8,>f8")
     msa = Masked(sa, [(False, True), (False, False)])
