@@ -10,7 +10,9 @@ import numpy as np
 import pytest
 
 from astropy.io import fits
+from astropy.tests.helper import CI
 from astropy.utils import data, misc
+from astropy.utils.exceptions import AstropyDeprecationWarning
 
 
 def test_isiterable():
@@ -32,8 +34,8 @@ def test_api_lookup():
     try:
         strurl = misc.find_api_page("astropy.utils.misc", "dev", False, timeout=5)
         objurl = misc.find_api_page(misc, "dev", False, timeout=5)
-    except urllib.error.URLError:
-        if os.environ.get("CI", False):
+    except (urllib.error.URLError, TimeoutError):
+        if CI:
             pytest.xfail("Timed out in CI")
         else:
             raise
@@ -45,13 +47,21 @@ def test_api_lookup():
     )
 
     # Try a non-dev version
-    objurl = misc.find_api_page(misc, "v3.2.1", False, timeout=3)
+    objurl = misc.find_api_page(misc, "stable", False, timeout=3)
     assert (
         objurl
-        == "https://docs.astropy.org/en/v3.2.1/utils/index.html#module-astropy.utils.misc"
+        == "https://docs.astropy.org/en/stable/utils/ref_api.html#module-astropy.utils.misc"
     )
 
 
+def test_is_path_hidden_deprecation():
+    with pytest.warns(
+        AstropyDeprecationWarning, match="^The is_path_hidden function is deprecated"
+    ):
+        misc.is_path_hidden("data")
+
+
+# This is the only test that uses astropy/utils/tests/data/.hidden_file.txt
 def test_skip_hidden():
     path = data.get_pkg_data_path("data")
     for root, dirs, files in os.walk(path):
@@ -60,11 +70,13 @@ def test_skip_hidden():
         # break after the first level since the data dir contains some other
         # subdirectories that don't have these files
         break
-
-    for root, dirs, files in misc.walk_skip_hidden(path):
-        assert ".hidden_file.txt" not in files
-        assert "local.dat" in files
-        break
+    with pytest.warns(
+        AstropyDeprecationWarning, match="^The .*_hidden function is deprecated"
+    ):
+        for root, dirs, files in misc.walk_skip_hidden(path):
+            assert ".hidden_file.txt" not in files
+            assert "local.dat" in files
+            break
 
 
 def test_JsonCustomEncoder():
@@ -72,7 +84,7 @@ def test_JsonCustomEncoder():
 
     assert json.dumps(np.arange(3), cls=misc.JsonCustomEncoder) == "[0, 1, 2]"
     assert json.dumps(1 + 2j, cls=misc.JsonCustomEncoder) == "[1.0, 2.0]"
-    assert json.dumps({1, 2, 1}, cls=misc.JsonCustomEncoder) == "[1, 2]"
+    assert json.dumps({1, 2}, cls=misc.JsonCustomEncoder) == "[1, 2]"
     assert (
         json.dumps(b"hello world \xc3\x85", cls=misc.JsonCustomEncoder)
         == '"hello world \\u00c5"'
