@@ -23,10 +23,10 @@ from .frame import EllipticalFrame, RectangularFrame1D
 from .grid_paths import get_gridline_path, get_lon_lat_path
 from .ticklabels import TickLabels
 from .ticks import Ticks
+from .utils import MATPLOTLIB_LT_3_8
 
 __all__ = ["CoordinateHelper"]
 
-
 # Matplotlib's gridlines use Line2D, but ours use PathPatch.
 # Patches take a slightly different format of linestyle argument.
 LINES_TO_PATCHES_LINESTYLE = {
@@ -74,8 +74,8 @@ class CoordinateHelper:
         The unit that this coordinate is in given the output of transform.
     format_unit : `~astropy.units.Unit`, optional
         The unit to use to display the coordinates.
-    coord_wrap : float
-        The angle at which the longitude wraps (defaults to 360)
+    coord_wrap : `astropy.units.Quantity`
+        The angle at which the longitude wraps (defaults to 360 degrees).
     frame : `~astropy.visualization.wcsaxes.frame.BaseFrame`
         The frame of the :class:`~astropy.visualization.wcsaxes.WCSAxes`.
     """
@@ -167,7 +167,6 @@ class CoordinateHelper:
             is recommended. By default, 'lines' is used if the transform has
             an inverse, otherwise 'contours' is used.
         """
-
         if grid_type == "lines" and not self.transform.has_inverse:
             raise ValueError(
                 "The specified transform has no inverse, so the "
@@ -201,14 +200,20 @@ class CoordinateHelper:
         ----------
         coord_type : str
             One of 'longitude', 'latitude' or 'scalar'
-        coord_wrap : float, optional
-            The value to wrap at for angular coordinates
+        coord_wrap : `~astropy.units.Quantity`, optional
+            The value to wrap at for angular coordinates.
         """
-
         self.coord_type = coord_type
 
+        if coord_wrap is not None and not isinstance(coord_wrap, u.Quantity):
+            warnings.warn(
+                "Passing 'coord_wrap' as a number is deprecated. Use a Quantity with units convertible to angular degrees instead.",
+                AstropyDeprecationWarning,
+            )
+            coord_wrap = coord_wrap * u.deg
+
         if coord_type == "longitude" and coord_wrap is None:
-            self.coord_wrap = 360
+            self.coord_wrap = 360 * u.deg
         elif coord_type != "longitude" and coord_wrap is not None:
             raise NotImplementedError(
                 "coord_wrap is not yet supported for non-longitude coordinates"
@@ -263,7 +268,6 @@ class CoordinateHelper:
             depending on whether Matplotlib is using LaTeX or MathTex. To
             get plain ASCII strings, use format='ascii'.
         """
-
         if not hasattr(self, "_fl_spacing"):
             return ""  # _update_ticks has not been called yet
 
@@ -274,7 +278,7 @@ class CoordinateHelper:
                 value *= self._coord_scale_to_deg
 
             if self.coord_type == "longitude":
-                value = wrap_angle_at(value, self.coord_wrap)
+                value = wrap_angle_at(value, self.coord_wrap.to_value(u.deg))
             value = value * u.degree
             value = value.to_value(fl._unit)
 
@@ -360,7 +364,6 @@ class CoordinateHelper:
         direction : {'in','out'}, optional
             Whether the ticks should point inwards or outwards.
         """
-
         if sum([values is None, spacing is None, number is None]) < 2:
             raise ValueError(
                 "At most one of values, spacing, or number should be specified"
@@ -401,7 +404,7 @@ class CoordinateHelper:
 
     def set_ticks_position(self, position):
         """
-        Set where ticks should appear
+        Set where ticks should appear.
 
         Parameters
         ----------
@@ -456,7 +459,7 @@ class CoordinateHelper:
 
     def set_ticklabel_position(self, position):
         """
-        Set where tick labels should appear
+        Set where tick labels should appear.
 
         Parameters
         ----------
@@ -512,7 +515,7 @@ class CoordinateHelper:
 
     def get_axislabel(self):
         """
-        Get the text for the axis label
+        Get the text for the axis label.
 
         Returns
         -------
@@ -553,7 +556,7 @@ class CoordinateHelper:
 
     def set_axislabel_position(self, position):
         """
-        Set where axis labels should appear
+        Set where axis labels should appear.
 
         Parameters
         ----------
@@ -615,25 +618,33 @@ class CoordinateHelper:
                     p.draw(renderer)
 
             elif self._grid is not None:
-                for line in self._grid.collections:
-                    line.set(**self.grid_lines_kwargs)
-                    line.draw(renderer)
+                if MATPLOTLIB_LT_3_8:
+                    for line in self._grid.collections:
+                        line.set(**self.grid_lines_kwargs)
+                        line.draw(renderer)
+                else:
+                    self._grid.set(**self.grid_lines_kwargs)
+                    self._grid.draw(renderer)
 
         renderer.close_group("grid lines")
 
-    def _draw_ticks(self, renderer, bboxes, ticklabels_bbox):
+    def _draw_ticks(self, renderer, existing_bboxes):
         """
         Draw all ticks and ticklabels.
-        """
 
+        Parameters
+        ----------
+        existing_bboxes : list[Bbox]
+            All bboxes for ticks that have already been drawn by other
+            coordinates.
+        """
         renderer.open_group("ticks")
         self.ticks.draw(renderer)
-        self.ticklabels.draw(
-            renderer,
-            bboxes=bboxes,
-            ticklabels_bbox=ticklabels_bbox,
-            tick_out_size=self.ticks.out_size,
-        )
+
+        self.ticklabels._tick_out_size = self.ticks.out_size
+
+        self.ticklabels._set_existing_bboxes(existing_bboxes)
+        self.ticklabels.draw(renderer)
 
         renderer.close_group("ticks")
 
@@ -768,8 +779,8 @@ class CoordinateHelper:
                     w1 = w1 * self._coord_scale_to_deg
                     w2 = w2 * self._coord_scale_to_deg
 
-                w1 = wrap_angle_at(w1, self.coord_wrap)
-                w2 = wrap_angle_at(w2, self.coord_wrap)
+                w1 = wrap_angle_at(w1, self.coord_wrap.to_value(u.deg))
+                w2 = wrap_angle_at(w2, self.coord_wrap.to_value(u.deg))
                 with np.errstate(invalid="ignore"):
                     w1[w2 - w1 > 180.0] += 360
                     w2[w1 - w2 > 180.0] += 360
@@ -859,7 +870,7 @@ class CoordinateHelper:
                     if self._coord_scale_to_deg is not None:
                         t *= self._coord_scale_to_deg
 
-                    world = wrap_angle_at(t, self.coord_wrap)
+                    world = wrap_angle_at(t, self.coord_wrap.to_value(u.deg))
 
                     if self._coord_scale_to_deg is not None:
                         world /= self._coord_scale_to_deg
@@ -955,6 +966,8 @@ class CoordinateHelper:
         tick_world_coordinates_values = tick_world_coordinates.to_value(self.coord_unit)
 
         n_coord = len(tick_world_coordinates_values)
+        if n_coord == 0:
+            return
 
         from . import conf
 
@@ -1119,8 +1132,11 @@ class CoordinateHelper:
 
     def _clear_grid_contour(self):
         if hasattr(self, "_grid") and self._grid:
-            for line in self._grid.collections:
-                line.remove()
+            if MATPLOTLIB_LT_3_8:
+                for line in self._grid.collections:
+                    line.remove()
+            else:
+                self._grid.remove()
 
     def _update_grid_contour(self):
         if self.coord_index is None:
@@ -1228,7 +1244,6 @@ class CoordinateHelper:
             The style of the grid lines (accepts any valid Matplotlib line
             style).
         """
-
         # First do some sanity checking on the keyword arguments
 
         # colors= is a fallback default for color and labelcolor
