@@ -59,7 +59,7 @@ CUSTOM_UNITS = {
 
 class BaseFormatterLocator:
     """
-    A joint formatter/locator
+    A joint formatter/locator.
     """
 
     def __init__(
@@ -99,7 +99,7 @@ class BaseFormatterLocator:
         if not values.unit.is_equivalent(self._unit):
             raise UnitsError(
                 "value should be in units compatible with "
-                "coordinate units ({}) but found {}".format(self._unit, values.unit)
+                f"coordinate units ({self._unit}) but found {values.unit}"
             )
         self._number = None
         self._spacing = None
@@ -154,7 +154,12 @@ class BaseFormatterLocator:
 
 class AngleFormatterLocator(BaseFormatterLocator):
     """
-    A joint formatter/locator
+    A joint formatter/locator.
+
+    Parameters
+    ----------
+    number : int, optional
+        Number of ticks.
     """
 
     def __init__(
@@ -348,6 +353,9 @@ class AngleFormatterLocator(BaseFormatterLocator):
                 # spacing was manually specified
                 spacing_value = self.spacing.to_value(self._unit)
 
+            elif self.number == 0:
+                return [] * self._unit, np.nan * self._unit
+
             elif self.number is not None:
                 # number of ticks was specified, work out optimal spacing
 
@@ -491,7 +499,7 @@ class AngleFormatterLocator(BaseFormatterLocator):
 
 class ScalarFormatterLocator(BaseFormatterLocator):
     """
-    A joint formatter/locator
+    A joint formatter/locator.
     """
 
     def __init__(
@@ -503,15 +511,12 @@ class ScalarFormatterLocator(BaseFormatterLocator):
         unit=None,
         format_unit=None,
     ):
-        if unit is not None:
-            unit = unit
-            format_unit = format_unit or unit
-        elif spacing is not None:
-            unit = spacing.unit
-            format_unit = format_unit or spacing.unit
-        elif values is not None:
-            unit = values.unit
-            format_unit = format_unit or values.unit
+        if unit is None:
+            if spacing is not None:
+                unit = spacing.unit
+            elif values is not None:
+                unit = values.unit
+        format_unit = format_unit or unit
 
         super().__init__(
             values=values,
