@@ -19,8 +19,9 @@ from astropy import units as u
 from astropy import wcs
 from astropy.coordinates import SkyCoord
 from astropy.io import fits
+from astropy.io.fits.verify import VerifyWarning
 from astropy.nddata import Cutout2D
-from astropy.tests.helper import assert_quantity_allclose
+from astropy.tests.helper import PYTEST_LT_8_0, assert_quantity_allclose
 from astropy.utils.data import (
     get_pkg_data_contents,
     get_pkg_data_filename,
@@ -604,7 +605,7 @@ def test_all_world2pix(
         [i.flatten() for i in np.meshgrid(*map(range, naxesi_l, naxesi_u))]
     )[0]
 
-    # Generage random data (in image coordinates):
+    # Generate random data (in image coordinates):
     with NumpyRNGContext(123456789):
         rnd_pix = np.random.rand(random_npts, ncoord)
 
@@ -968,7 +969,14 @@ def test_sip_tpv_agreement():
         os.path.join("data", "tpvonly.hdr"), encoding="binary"
     )
 
-    with pytest.warns(wcs.FITSFixedWarning):
+    if PYTEST_LT_8_0:
+        ctx = nullcontext()
+    else:
+        ctx = pytest.warns(
+            AstropyWarning, match="Some non-standard WCS keywords were excluded"
+        )
+
+    with pytest.warns(wcs.FITSFixedWarning), ctx:
         w_sip = wcs.WCS(sip_header)
         w_tpv = wcs.WCS(tpv_header)
 
@@ -1005,11 +1013,21 @@ def test_tpv_ctype_sip():
     sip_header["CTYPE1"] = "RA---TAN-SIP"
     sip_header["CTYPE2"] = "DEC--TAN-SIP"
 
+    if PYTEST_LT_8_0:
+        ctx1 = ctx2 = nullcontext()
+    else:
+        ctx1 = pytest.warns(
+            wcs.FITSFixedWarning, match=".*RADECSYS keyword is deprecated, use RADESYSa"
+        )
+        ctx2 = pytest.warns(
+            wcs.FITSFixedWarning, match=".*Set MJD-OBS to .* from DATE-OBS"
+        )
+
     with pytest.warns(
         wcs.FITSFixedWarning,
         match="Removed redundant SCAMP distortion parameters "
         "because SIP parameters are also present",
-    ):
+    ), ctx1, ctx2:
         w_sip = wcs.WCS(sip_header)
 
     assert w_sip.sip is not None
@@ -1026,11 +1044,21 @@ def test_tpv_ctype_tpv():
     sip_header["CTYPE1"] = "RA---TPV"
     sip_header["CTYPE2"] = "DEC--TPV"
 
+    if PYTEST_LT_8_0:
+        ctx1 = ctx2 = nullcontext()
+    else:
+        ctx1 = pytest.warns(
+            wcs.FITSFixedWarning, match=".*RADECSYS keyword is deprecated, use RADESYSa"
+        )
+        ctx2 = pytest.warns(
+            wcs.FITSFixedWarning, match=".*Set MJD-OBS to .* from DATE-OBS"
+        )
+
     with pytest.warns(
         wcs.FITSFixedWarning,
         match="Removed redundant SIP distortion parameters "
         "because CTYPE explicitly specifies TPV distortions",
-    ):
+    ), ctx1, ctx2:
         w_sip = wcs.WCS(sip_header)
 
     assert w_sip.sip is None
@@ -1047,11 +1075,21 @@ def test_tpv_ctype_tan():
     sip_header["CTYPE1"] = "RA---TAN"
     sip_header["CTYPE2"] = "DEC--TAN"
 
+    if PYTEST_LT_8_0:
+        ctx1 = ctx2 = nullcontext()
+    else:
+        ctx1 = pytest.warns(
+            wcs.FITSFixedWarning, match=".*RADECSYS keyword is deprecated, use RADESYSa"
+        )
+        ctx2 = pytest.warns(
+            wcs.FITSFixedWarning, match=".*Set MJD-OBS to .* from DATE-OBS"
+        )
+
     with pytest.warns(
         wcs.FITSFixedWarning,
         match="Removed redundant SIP distortion parameters "
         "because SCAMP' PV distortions are also present",
-    ):
+    ), ctx1, ctx2:
         w_sip = wcs.WCS(sip_header)
 
     assert w_sip.sip is None
@@ -1421,7 +1459,15 @@ def test_to_fits_1():
     Test to_fits() with LookupTable distortion.
     """
     fits_name = get_pkg_data_filename("data/dist.fits")
-    with pytest.warns(AstropyDeprecationWarning):
+
+    if PYTEST_LT_8_0:
+        ctx = nullcontext()
+    else:
+        ctx = pytest.warns(
+            wcs.FITSFixedWarning, match="The WCS transformation has more axes"
+        )
+
+    with pytest.warns(AstropyDeprecationWarning), ctx:
         w = wcs.WCS(fits_name)
     wfits = w.to_fits()
     assert isinstance(wfits, fits.HDUList)
@@ -1556,7 +1602,7 @@ def test_cunit():
     assert w1.wcs.cunit != ["a", "b", "c"]
     # Comparison is not implemented TypeError will raise
     with pytest.raises(TypeError):
-        w1.wcs.cunit < w2.wcs.cunit
+        w1.wcs.cunit < w2.wcs.cunit  # noqa: B015
 
 
 class TestWcsWithTime:
@@ -1694,8 +1740,13 @@ def test_distortion_header(tmp_path):
     cen = np.array((50, 50))
     siz = np.array((20, 20))
 
+    if PYTEST_LT_8_0:
+        ctx = nullcontext()
+    else:
+        ctx = pytest.warns(VerifyWarning)
+
     with fits.open(path) as hdulist:
-        with pytest.warns(wcs.FITSFixedWarning):
+        with ctx, pytest.warns(wcs.FITSFixedWarning):
             w = wcs.WCS(hdulist[0].header)
         cut = Cutout2D(hdulist[0].data, position=cen, size=siz, wcs=w)
 
@@ -1794,7 +1845,7 @@ def test_swapaxes_same_val_roundtrip():
     w.wcs.cdelt = [1.0, 1.0, 1.0]
     w.wcs.set()
     axes_order = [3, 2, 1]
-    axes_order0 = list(i - 1 for i in axes_order)
+    axes_order0 = [i - 1 for i in axes_order]
     ws = w.sub(axes_order)
     imcoord = np.array([3, 5, 7])
     imcoords = imcoord[axes_order0]
